@@ -131,12 +131,12 @@ _e_alert_drm_cb_key_down(void *data EINA_UNUSED, int type EINA_UNUSED, void *eve
    ev = event;
    if (!strcmp(ev->key, "F12"))
      {
-        ret = 2;
+        ret = 1;
         ecore_main_loop_quit();
      }
    else if (!strcmp(ev->key, "F1"))
      {
-        ret = 1;
+        ret = 2;
         ecore_main_loop_quit();
      }
 
@@ -407,6 +407,14 @@ _e_alert_drm_connect(void)
    output = ecore_drm2_output_find(dev, 0, 0);
    if (output) e_drm2_output_info_get(output, NULL, NULL, &sw, &sh, NULL);
    fprintf(stderr, "\tOutput Size: %d %d\n", sw, sh);
+   // force symbol usage to get rid of warnings for release.
+   // i think we'll replace all the x and drm2 stuff in e_alert with normal
+   // full fat efl stuff. it'll reduce duplication and simplify this
+   // e_alert stuff a lot with the downside of a broken efl breaking
+   // e_alert, but then a broken efl will affect it already. i'll look into
+   // a text mode fallback - so a crash handler for the crash handler... :)
+   // turtles all the way down.
+   e_drm2_output_rotation_set(output, e_drm2_output_rotation_get(output));
 
    ecore_event_handler_add(ECORE_EVENT_KEY_DOWN,
                            _e_alert_drm_cb_key_down, NULL);
@@ -581,8 +589,8 @@ main(int argc, char **argv)
 #endif
    ecore_shutdown();
 
-   /* ret == 1 => restart e => exit code 1 */
-   /* ret == 2 => exit e => any code will do that */
+   /* ret == 1 => exit e => exit code 1 */
+   /* ret == 2 => restart e => any code will do that */
    return ret;
 }
 #ifndef HAVE_WAYLAND_ONLY
@@ -914,9 +922,9 @@ _e_alert_handle_key_press(xcb_generic_event_t *event)
    key = xcb_key_symbols_get_keysym(symbols, ev->detail, 0);
 
    if (key == XK_F1)
-     r = 1;
-   else if (key == XK_F12)
      r = 2;
+   else if (key == XK_F12)
+     r = 1;
 
    xcb_key_symbols_free(symbols);
 
