@@ -48,7 +48,7 @@ static void
 _do_profile(E_Desk *desk, E_Randr2_Screen *sc)
 {
    int scale = 100;
-   char buf[PATH_MAX], buf2[PATH_MAX];
+   char buf[PATH_MAX], buf2[PATH_MAX + 256];
 
    eina_stringshare_del(desk->window_profile);
    desk->window_profile = NULL;
@@ -77,7 +77,8 @@ _do_profile(E_Desk *desk, E_Randr2_Screen *sc)
                       "%s/enlightenment/utils/enlightenment_elm_cfgtool "
                       "set %s %s 'scale-mul %i'",
                       e_prefix_lib_get(), sc->config.profile, buf, scale);
-             system(buf2);
+             if (system(buf2) != 0)
+               ERR("Error code from trying to run \"%s\"", buf2);
           }
      }
    desk->window_profile = eina_stringshare_add(buf);
