@@ -31,7 +31,7 @@ struct _E_Exec_Watch
 {
    void        (*func)(void *data, E_Exec_Instance *inst, E_Exec_Watch_Type type);
    const void *data;
-   Eina_Bool   delete_me : 1;
+   Eina_Bool   delete_me E_BITFIELD;
 };
 
 struct _E_Config_Dialog_Data
@@ -102,7 +102,6 @@ e_exec_init(void)
 EINTERN int
 e_exec_shutdown(void)
 {
-   e_exehist_startup_id_set(startup_id);
    if (_e_exec_exit_handler) ecore_event_handler_del(_e_exec_exit_handler);
    if (_e_exec_desktop_update_handler)
      ecore_event_handler_del(_e_exec_desktop_update_handler);
