@@ -214,13 +214,18 @@ e_int_menus_main_new(void)
    e_menu_item_submenu_set(mi, subm);
    e_object_data_set(E_OBJECT(subm), dat);
 
-   subm = e_int_menus_lost_clients_new();
-   e_object_data_set(E_OBJECT(subm), dat);
-   dat->lost_clients = subm;
-   mi = e_menu_item_new(m);
-   e_menu_item_label_set(mi, _("Lost Windows"));
-   e_util_menu_item_theme_icon_set(mi, "preferences-windows-lost");
-   e_menu_item_submenu_set(mi, subm);
+#ifndef HAVE_WAYLAND
+   if (e_comp->comp_type == E_PIXMAP_TYPE_X)
+     {
+        subm = e_int_menus_lost_clients_new();
+        e_object_data_set(E_OBJECT(subm), dat);
+        dat->lost_clients = subm;
+        mi = e_menu_item_new(m);
+        e_menu_item_label_set(mi, _("Lost Windows"));
+        e_util_menu_item_theme_icon_set(mi, "preferences-windows-lost");
+        e_menu_item_submenu_set(mi, subm);
+     }
+#endif
 
    l = _e_int_menus_augmentation_find("main/3");
    if (l) _e_int_menus_augmentation_add(m, l);
@@ -362,7 +367,7 @@ e_int_menus_desktops_new(void)
    e_menu_item_callback_set(mi, _e_int_menus_wallpaper_cb, NULL);
 
    mi = e_menu_item_new(m);
-   e_menu_item_label_set(mi, _("Add Bryce"));
+   e_menu_item_label_set(mi, _("Add Gadget Bar (EXPERIMENTAL)"));
    e_util_menu_item_theme_icon_set(mi, "list-add");
    e_menu_item_callback_set(mi, _e_int_menus_bryce_cb, NULL);
 
@@ -1637,7 +1642,10 @@ _e_int_menus_clients_title_abbrv(const char *title)
    /* Advance to the end of the first half of the string. */
    len = 0;
    for (len2 = (max_len / 2); len2; len2--)
-     if (!eina_unicode_utf8_next_get(title, &len)) break;
+     {
+        Eina_Unicode u = eina_unicode_utf8_next_get(title, &len);
+        if ((!u) || ((u >= 0xdc80) && (u <= 0xdcff))) break;
+     }
 
    strncat(abbvptr, title, len);
    abbvptr += len;
