@@ -3,6 +3,8 @@
 # include <sys/prctl.h>
 #endif
 
+#include "valgrind.h"
+
 #define MAX_LEVEL 80
 
 #define TS_DO
@@ -134,7 +136,7 @@ _xdg_data_dirs_augment(void)
 {
    const char *s;
    const char *p = e_prefix_get();
-   char newpath[4096], buf[4096];
+   char newpath[PATH_MAX], buf[PATH_MAX + PATH_MAX + 200];
 
    if (!p) return;
 
@@ -284,11 +286,15 @@ main(int argc, char **argv)
    if (getenv("E_START_MTRACK"))
      e_util_env_set("MTRACK", NULL);
    TS("Eina Init");
+   s = getenv("EINA_STATGEN");
+   if (!s) e_util_env_set("EINA_STATGEN", "1");
    if (!eina_init())
      {
         e_error_message_show(_("Enlightenment cannot initialize Eina!\n"));
         _e_main_shutdown(-1);
      }
+   if (!s) e_util_env_set("EINA_STATGEN", NULL);
+
    _e_main_shutdown_push(eina_shutdown);
    if (!e_log_init())
      {
@@ -378,6 +384,10 @@ main(int argc, char **argv)
    TS("EFX Init Done");
    _e_main_shutdown_push((void*)e_efx_shutdown);
 
+   /* Eio's eio_init internally calls efreet_init. Set XDG_MENU_PREFIX here      */
+   /* else efreet's efreet_menu_prefix symbol is set erroneously during eio_init. */
+   _xdg_data_dirs_augment();
+
    TS("EIO Init");
    if (!eio_init())
      {
@@ -442,8 +452,6 @@ main(int argc, char **argv)
 
    _idle_before = ecore_idle_enterer_before_add(_e_main_cb_idle_before, NULL);
 
-   _xdg_data_dirs_augment();
-
    TS("Ecore_Evas Init");
    if (!ecore_evas_init())
      {
@@ -816,9 +824,9 @@ main(int argc, char **argv)
    TS("E_Desklock Init Done");
    _e_main_shutdown_push(e_desklock_shutdown);
 
-   if (waslocked || (locked && ((!after_restart) || (!getenv("E_DESKLOCK_UNLOCKED")))))
+   if (waslocked || (locked && ((!after_restart))))
      {
-        e_desklock_show(EINA_TRUE);
+        e_desklock_show_manual(EINA_TRUE);
         e_screensaver_update();
      }
 
@@ -1281,7 +1289,7 @@ _e_main_parse_arguments(int argc, char **argv)
 
    /* we want to have been launched by enlightenment_start. there is a very */
    /* good reason we want to have been launched this way, thus check */
-   if (!getenv("E_START"))
+   if ((!getenv("E_START")) && (!RUNNING_ON_VALGRIND))
      {
         e_error_message_show(_("You are executing enlightenment directly. This is\n"
                                "bad. Please do not execute the \"enlightenment\"\n"
@@ -1313,10 +1321,21 @@ _e_main_cb_signal_exit(void *data EINA_UNUSED, int ev_type EINA_UNUSED, void *ev
    return ECORE_CALLBACK_RENEW;
 }
 
+static Ecore_Timer *hup_timer = NULL;
+
+static Eina_Bool
+_cb_hup_timer(void *data EINA_UNUSED)
+{
+   hup_timer = NULL;
+   if (!e_sys_on_the_way_out_get()) e_sys_action_do(E_SYS_RESTART, NULL);
+   return EINA_FALSE;
+}
+
 static Eina_Bool
 _e_main_cb_signal_hup(void *data EINA_UNUSED, int ev_type EINA_UNUSED, void *ev EINA_UNUSED)
 {
-   e_sys_action_do(E_SYS_RESTART, NULL);
+   if (hup_timer) ecore_timer_del(hup_timer);
+   hup_timer = ecore_timer_add(0.5, _cb_hup_timer, NULL);
    return ECORE_CALLBACK_RENEW;
 }
 
