@@ -81,9 +81,11 @@ static Eina_Bool    _e_menu_cb_scroll_animator(void *data);
 static void         _e_menu_cb_item_submenu_post_default(void *data, E_Menu *m, E_Menu_Item *mi);
 static void         _e_menu_category_free_cb(E_Menu_Category *cat);
 static void         _e_menu_cb_mouse_evas_down(void *data EINA_UNUSED, Evas_Object *obj EINA_UNUSED);
+static void         _e_menu_hide_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED);
 
 /* local subsystem globals */
 static Ecore_Window _e_menu_win = UINT_MAX;
+static Eina_Bool _e_menu_grabbed = EINA_FALSE;
 static Eina_List *_e_active_menus = NULL;
 static E_Menu_Item *_e_active_menu_item = NULL;
 static E_Menu_Item *_e_prev_active_menu_item = NULL;
@@ -198,6 +200,11 @@ e_menu_hide_all(void)
         m->in_active_list = 0;
         e_object_unref(E_OBJECT(m));
      }
+   if (_e_menu_grabbed)
+     {
+        e_comp_ungrab_input(1, 1);
+        _e_menu_grabbed = EINA_FALSE;
+     }
 }
 
 E_API E_Menu *
@@ -210,9 +217,18 @@ e_menu_new(void)
    m->cur.w = 1;
    m->cur.h = 1;
    m->category = NULL;
+   m->hold_mode = EINA_TRUE;
    return m;
 }
 
+E_API void
+e_menu_hold_mode_set(E_Menu *m, Eina_Bool hold_mode)
+{
+   E_OBJECT_CHECK(m);
+   E_OBJECT_TYPE_CHECK(m, E_MENU_TYPE);
+   m->hold_mode = hold_mode;
+}
+
 E_API void
 e_menu_activate_key(E_Menu *m, E_Zone *zone, int x, int y, int w, int h, int dir)
 {
@@ -470,6 +486,7 @@ e_menu_title_set(E_Menu *m, const char *title)
    if (title) m->header.title = eina_stringshare_add(title);
    else m->header.title = NULL;
    m->changed = 1;
+   if (!m->realized) return;
    edje_object_part_text_set(m->bg_object, "e.text.title", m->header.title);
    if (m->header.title)
      edje_object_signal_emit(m->bg_object, "e,action,show,title", "e");
@@ -766,8 +783,8 @@ e_menu_item_submenu_set(E_Menu_Item *mi, E_Menu *sub)
         e_theme_edje_object_set(o, "base/theme/menus",
                                 "e/widgets/menu/default/submenu");
         evas_object_pass_events_set(o, 1);
-        evas_object_show(o);
         elm_box_pack_end(mi->container_object, o);
+        evas_object_show(o);
         edje_object_size_min_calc(mi->submenu_object, &ww, &hh);
         mi->submenu_w = ww;
         mi->submenu_h = hh;
@@ -1092,6 +1109,7 @@ e_menu_idler_before(void)
    /* level state machine */
    Eina_List *l, *removals = NULL, *tmp;
    E_Menu *m;
+   int active_count = 0;
 
    if (pending_feed)
      {
@@ -1197,11 +1215,19 @@ e_menu_idler_before(void)
    /* del refcount to all menus we worked with */
    _e_menu_list_free_unref(tmp);
 
-   if (!_e_active_menus)
+   EINA_LIST_FOREACH(_e_active_menus, l, m)
+     {
+        if (m->active) active_count++;
+     }
+   if (!active_count)
      {
         if (_e_menu_win == e_comp->ee_win)
           {
-             e_comp_ungrab_input(1, 1);
+             if (_e_menu_grabbed)
+               {
+                  e_comp_ungrab_input(1, 1);
+                  _e_menu_grabbed = EINA_FALSE;
+               }
              _e_menu_win = UINT_MAX;
              e_bindings_disabled_set(0);
           }
@@ -1374,19 +1400,18 @@ _e_menu_item_realize(E_Menu_Item *mi)
         mi->separator_object = o;
         e_theme_edje_object_set(o, "base/theme/menus",
                                 "e/widgets/menu/default/separator");
-        evas_object_show(o);
         edje_object_size_min_calc(mi->separator_object, &ww, &hh);
         E_FILL(mi->separator_object);
         mi->separator_w = ww;
         mi->separator_h = hh;
+        evas_object_size_hint_min_set(mi->separator_object, ww, hh);
         elm_box_pack_end(mi->menu->container_object, mi->separator_object);
+        evas_object_show(o);
      }
    else
      {
         o = edje_object_add(mi->menu->evas);
         mi->bg_object = o;
-        evas_object_name_set(o, "mi->bg_object");
-        evas_object_data_set(o, "e_menu_item", mi);
         evas_object_event_callback_add(o, EVAS_CALLBACK_MOUSE_IN, _e_menu_cb_item_in, mi);
         evas_object_event_callback_add(o, EVAS_CALLBACK_MOUSE_OUT, _e_menu_cb_item_out, mi);
         evas_object_intercept_move_callback_add(o, _e_menu_cb_intercept_item_move, mi);
@@ -1403,11 +1428,7 @@ no_submenu_item:
              e_theme_edje_object_set(mi->bg_object, "base/theme/menus",
                                      "e/widgets/menu/default/item_bg");
           }
-        evas_object_show(o);
-
         o = elm_box_add(e_comp->elm);
-        evas_object_name_set(o, "mi->container_object");
-        elm_box_homogeneous_set(o, 0);
         mi->container_object = o;
         elm_box_horizontal_set(o, 1);
         evas_object_show(o);
@@ -1416,39 +1437,36 @@ no_submenu_item:
         if (mi->check)
           {
              o = edje_object_add(mi->menu->evas);
-             evas_object_name_set(o, "mi->toggle_object");
              mi->toggle_object = o;
              e_theme_edje_object_set(o, "base/theme/menus",
                                      "e/widgets/menu/default/check");
-             evas_object_show(o);
-             elm_box_pack_end(mi->container_object, o);
              edje_object_size_min_calc(mi->toggle_object, &ww, &hh);
              mi->toggle_w = ww;
              mi->toggle_h = hh;
              E_WEIGHT(mi->toggle_object, 0, 1);
              E_FILL(mi->toggle_object);
              evas_object_size_hint_min_set(mi->toggle_object, ww, hh);
+             elm_box_pack_end(mi->container_object, o);
+             evas_object_show(o);
           }
         else if (mi->radio)
           {
              o = edje_object_add(mi->menu->evas);
-             evas_object_name_set(o, "mi->toggle_object");
              mi->toggle_object = o;
              e_theme_edje_object_set(o, "base/theme/menus",
                                      "e/widgets/menu/default/radio");
-             evas_object_show(o);
-             elm_box_pack_end(mi->container_object, o);
              edje_object_size_min_calc(mi->toggle_object, &ww, &hh);
              mi->toggle_w = ww;
              mi->toggle_h = hh;
              E_WEIGHT(mi->toggle_object, 0, 1);
              E_FILL(mi->toggle_object);
              evas_object_size_hint_min_set(mi->toggle_object, ww, hh);
+             elm_box_pack_end(mi->container_object, o);
+             evas_object_show(o);
           }
         else
           {
              o = evas_object_rectangle_add(mi->menu->evas);
-             evas_object_name_set(o, "mi->toggle_object");
              mi->toggle_object = o;
              evas_object_color_set(o, 0, 0, 0, 0);
              elm_box_pack_end(mi->container_object, o);
@@ -1461,9 +1479,7 @@ no_submenu_item:
              if (e_theme_edje_object_set(o, "base/theme/menus",
                                          "e/widgets/menu/default/icon"))
                {
-                  evas_object_name_set(o, "mi->icon_bg_object");
                   mi->icon_bg_object = o;
-                  evas_object_show(o);
                }
              else
                {
@@ -1493,7 +1509,6 @@ no_submenu_item:
                        if (edje_object_file_set(o, mi->icon, mi->icon_key))
                          {
                             mi->icon_object = o;
-                            evas_object_name_set(o, "mi->icon_object");
                             edje_object_size_max_get(o, &iww, &ihh);
                             icon_w = iww;
                             icon_h = ihh;
@@ -1507,9 +1522,8 @@ no_submenu_item:
                   if (!mi->icon_object)
                     {
                        o = e_icon_add(mi->menu->evas);
-                       evas_object_name_set(o, "mi->icon_object");
                        mi->icon_object = o;
-                       e_icon_scale_size_set(o, e_util_icon_size_normalize(24 * e_scale));
+                       e_icon_scale_size_set(o, e_util_icon_size_normalize(96 * e_scale));
                        e_icon_preload_set(mi->icon_object, 1);
                        e_icon_file_set(o, mi->icon);
                        e_icon_fill_inside_set(mi->icon_object, 1);
@@ -1534,28 +1548,28 @@ no_submenu_item:
                   edje_object_size_min_calc(mi->icon_bg_object, &ww, &hh);
                   mi->icon_w = ww;
                   mi->icon_h = hh;
-                  elm_box_pack_end(mi->container_object, mi->icon_bg_object);
+                  evas_object_size_hint_min_set(mi->icon_bg_object, ww, hh);
                   E_WEIGHT(mi->icon_bg_object, 0, 1);
                   E_FILL(mi->icon_bg_object);
-                  evas_object_size_hint_min_set(mi->icon_bg_object, ww, hh);
+                  elm_box_pack_end(mi->container_object, mi->icon_bg_object);
+                  evas_object_show(mi->icon_bg_object);
                }
              else
                {
                   o = edje_object_add(mi->menu->evas);
-                  evas_object_name_set(o, "mi->icon_bg_object");
                   e_icon_size_get(mi->icon_object, &icon_w, &icon_h);
                   mi->icon_w = icon_w;
                   mi->icon_h = icon_h;
-                  elm_box_pack_end(mi->container_object, o);
                   E_WEIGHT(mi->icon_object, 0, 1);
-                  E_FILL(mi->icon_bg_object);
+                  E_FILL(mi->icon_object);
                   evas_object_size_hint_min_set(mi->icon_object, ww, hh);
+                  elm_box_pack_end(mi->container_object, o);
+                  evas_object_show(o);
                }
           }
         else
           {
              o = evas_object_rectangle_add(mi->menu->evas);
-             evas_object_name_set(o, "mi->icon_object");
              mi->icon_object = o;
              evas_object_color_set(o, 0, 0, 0, 0);
              elm_box_pack_end(mi->container_object, o);
@@ -1564,25 +1578,23 @@ no_submenu_item:
         if (mi->label)
           {
              o = edje_object_add(mi->menu->evas);
-             evas_object_name_set(o, "mi->label_object");
              mi->label_object = o;
              e_theme_edje_object_set(o, "base/theme/menus",
                                      "e/widgets/menu/default/label");
              /* default label */
              edje_object_part_text_set(o, "e.text.label", mi->label);
-             evas_object_show(o);
-             elm_box_pack_end(mi->container_object, o);
              edje_object_size_min_calc(mi->label_object, &ww, &hh);
              mi->label_w = ww;
              mi->label_h = hh;
+             evas_object_size_hint_min_set(mi->label_object, ww, hh);
              E_EXPAND(mi->label_object);
              E_FILL(mi->label_object);
-             evas_object_size_hint_min_set(mi->label_object, ww, hh);
+             elm_box_pack_end(mi->container_object, o);
+             evas_object_show(o);
           }
         else
           {
              o = evas_object_rectangle_add(mi->menu->evas);
-             evas_object_name_set(o, "mi->label_object");
              mi->label_object = o;
              evas_object_color_set(o, 0, 0, 0, 0);
              elm_box_pack_end(mi->container_object, o);
@@ -1590,23 +1602,21 @@ no_submenu_item:
         if ((mi->submenu) || (mi->submenu_pre_cb.func))
           {
              o = edje_object_add(mi->menu->evas);
-             evas_object_name_set(o, "mi->submenu_object");
              mi->submenu_object = o;
              e_theme_edje_object_set(o, "base/theme/menus",
                                      "e/widgets/menu/default/submenu");
-             evas_object_show(o);
-             elm_box_pack_end(mi->container_object, o);
              edje_object_size_min_calc(mi->submenu_object, &ww, &hh);
              mi->submenu_w = ww;
              mi->submenu_h = hh;
              E_WEIGHT(mi->submenu_object, 0, 1);
              E_FILL(mi->submenu_object);
              evas_object_size_hint_min_set(mi->submenu_object, ww, hh);
+             elm_box_pack_end(mi->container_object, o);
+             evas_object_show(o);
           }
         else
           {
              o = evas_object_rectangle_add(mi->menu->evas);
-             evas_object_name_set(o, "mi->submenu_object");
              mi->submenu_object = o;
              evas_object_color_set(o, 0, 0, 0, 0);
              elm_box_pack_end(mi->container_object, o);
@@ -1616,6 +1626,8 @@ no_submenu_item:
                                  mi->container_object);
 
         elm_box_pack_end(mi->menu->container_object, mi->bg_object);
+        evas_object_show(mi->container_object);
+        evas_object_show(mi->bg_object);
      }
    if (mi->active) e_menu_item_active_set(mi, 1);
    if (mi->toggle) e_menu_item_toggle_set(mi, 1);
@@ -1639,7 +1651,6 @@ _e_menu_realize(E_Menu *m)
 
    o = edje_object_add(m->evas);
    m->bg_object = o;
-   evas_object_name_set(o, "menu->bg_object");
    e_theme_edje_object_set(o, "base/theme/menus", "e/widgets/menu/default/background");
    if (m->header.title)
      {
@@ -1649,29 +1660,27 @@ _e_menu_realize(E_Menu *m)
      }
 
    m->comp_object = e_comp_object_util_add(o, E_COMP_OBJECT_TYPE_MENU);
-   evas_object_data_set(m->comp_object, "E_Menu", m);
    if (!m->parent_item)
      e_comp_object_util_autoclose(m->comp_object, _e_menu_cb_mouse_evas_down, _e_menu_cb_key_down, m);
-   evas_object_name_set(m->comp_object, "m->comp_object");
    evas_object_event_callback_add(m->comp_object, EVAS_CALLBACK_HIDE, _e_menu_hide_cb, m);
    evas_object_layer_set(m->comp_object, E_LAYER_MENU);
-   evas_object_move(m->comp_object, m->cur.x, m->cur.y);
-   evas_object_resize(m->comp_object, m->cur.w, m->cur.h);
+   evas_object_geometry_set(m->comp_object, m->cur.x, m->cur.y, m->cur.w, m->cur.h);
 
    o = elm_box_add(e_comp->elm);
-   evas_object_name_set(o, "menu->container_object");
    m->container_object = o;
    evas_object_intercept_move_callback_add(o, _e_menu_cb_intercept_container_move, m);
    evas_object_intercept_resize_callback_add(o, _e_menu_cb_intercept_container_resize, m);
-   elm_box_homogeneous_set(o, 0);
-   edje_object_part_swallow(m->bg_object, "e.swallow.content", m->container_object);
 
    EINA_LIST_FOREACH(m->items, l, mi)
      _e_menu_item_realize(mi);
 
+   edje_object_part_swallow(m->bg_object, "e.swallow.content", m->container_object);
+
    _e_menu_items_layout_update(m);
 
+
    evas_event_thaw(m->evas);
+   evas_event_thaw_eval(m->evas);
    m->realized = 1;
 }
 
@@ -1807,8 +1816,6 @@ _e_menu_items_layout_update(E_Menu *m)
 
         evas_object_size_hint_min_set(mi->container_object,
                                         min_w, min_h);
-        edje_object_part_swallow(mi->bg_object, "e.swallow.content",
-                                 mi->container_object);
         edje_object_size_min_calc(mi->bg_object, &mw, &mh);
         E_WEIGHT(mi->bg_object, 0, 1);
         E_FILL(mi->bg_object);
@@ -1818,7 +1825,6 @@ _e_menu_items_layout_update(E_Menu *m)
    elm_box_recalculate(m->container_object);
    evas_object_size_hint_min_get(m->container_object, &bw, &bh);
    evas_object_size_hint_max_set(m->container_object, bw, bh);
-   edje_object_part_swallow(m->bg_object, "e.swallow.content", m->container_object);
    edje_object_size_min_calc(m->bg_object, &mw, &mh);
    m->cur.w = mw;
    m->cur.h = mh;
@@ -1854,6 +1860,8 @@ _e_menu_unrealize(E_Menu *m)
    if (!m->realized) return;
    /* freeze+thaw here breaks the universe. don't do it. */
    //evas_event_freeze(m->evas);
+   if (m->comp_object)
+     evas_object_event_callback_del(m->comp_object, EVAS_CALLBACK_HIDE, _e_menu_hide_cb);
    if (m->cur.visible && m->comp_object && (!stopping))
      {
         /* force unref in smart object */
@@ -1867,10 +1875,6 @@ _e_menu_unrealize(E_Menu *m)
         E_FREE_FUNC(m->comp_object, evas_object_del);
         return;
      }
-   if (m->comp_object)
-     {
-        evas_object_event_callback_del_full(m->comp_object, EVAS_CALLBACK_HIDE, _e_menu_hide_cb, m);
-     }
    evas_object_hide(m->comp_object);
    evas_object_del(m->comp_object);
    if (stopping && m->comp_object) evas_object_unref(m->comp_object);
@@ -1905,6 +1909,7 @@ _e_menu_activate_internal(E_Menu *m, E_Zone *zone)
              _e_menu_win = UINT_MAX;
              return;
           }
+        _e_menu_grabbed = EINA_TRUE;
         e_bindings_disabled_set(1);
      }
    m->zone = zone;
@@ -2779,6 +2784,8 @@ static Eina_Bool
 _e_menu_cb_mouse_up(void *data EINA_UNUSED, int type EINA_UNUSED, void *event)
 {
    Ecore_Event_Mouse_Button *ev;
+   E_Menu *m;
+   Eina_List *l;
    unsigned int t;
    int ret = 0;
 
@@ -2786,6 +2793,18 @@ _e_menu_cb_mouse_up(void *data EINA_UNUSED, int type EINA_UNUSED, void *event)
    ev = event;
    if (ev->window != _e_menu_win) return ECORE_CALLBACK_RENEW;
 
+   if (!_e_menu_activate_floating)
+     {
+        EINA_LIST_FOREACH(_e_active_menus, l, m)
+          {
+             if (!m->hold_mode)
+               {
+                  _e_menu_activate_floating = 1;
+                  return ECORE_CALLBACK_PASS_ON;
+               }
+          }
+     }
+
    t = ev->timestamp - _e_menu_activate_time;
    if ((_e_menu_activate_time != 0) &&
        (t < (e_config->menus_click_drag_timeout * 1000)))
