@@ -55,9 +55,9 @@ struct _E_Pixmap
    Eina_List *free_buffers;
 #endif
 
-   Eina_Bool usable : 1;
-   Eina_Bool dirty : 1;
-   Eina_Bool image_argb : 1;
+   Eina_Bool usable E_BITFIELD;
+   Eina_Bool dirty E_BITFIELD;
+   Eina_Bool image_argb E_BITFIELD;
 };
 
 #ifdef HAVE_WAYLAND
@@ -796,11 +796,17 @@ e_pixmap_native_surface_init(E_Pixmap *cp, Evas_Native_Surface *ns)
         if (!cp->buffer) return EINA_FALSE;
         if (cp->buffer->dmabuf_buffer)
           {
+             static signed char use_hw_planes = -1;
              ns->type = EVAS_NATIVE_SURFACE_WL_DMABUF;
 
              ns->data.wl_dmabuf.attr = &cp->buffer->dmabuf_buffer->attributes;
              ns->data.wl_dmabuf.resource = cp->buffer->resource;
-             if (getenv("E_USE_HARDWARE_PLANES"))
+             if (use_hw_planes == -1)
+               {
+                  if (getenv("E_USE_HARDWARE_PLANES")) use_hw_planes = 1;
+                  else use_hw_planes = 0;
+               }
+             if (use_hw_planes)
                {
                   ns->data.wl_dmabuf.scanout.handler = _e_pixmap_scanout_handler;
                   ns->data.wl_dmabuf.scanout.data = cp->buffer;
@@ -1129,7 +1135,7 @@ e_pixmap_alias(E_Pixmap *cp, E_Pixmap_Type type, ...)
         id = va_arg(l, int64_t);
         if (!aliases[type])
           aliases[type] = eina_hash_int64_new(NULL);
-        cp2 = eina_hash_find(aliases[type], &xwin);
+        cp2 = eina_hash_find(aliases[type], &id);
         if ((cp2) && (!cp)) cp2->alias = 0;
         else if (cp) cp->alias = id;
         eina_hash_set(aliases[type], &id, cp);
