@@ -479,6 +479,7 @@ _config_really_apply(E_Randr2_Screen *s, E_Config_Randr2_Screen *cs)
         s->config.mode.h = cs->mode_h;
         s->config.mode.refresh = cs->mode_refresh;
         s->config.mode.preferred = EINA_FALSE;
+        printf("RRR: really apply rotation=%i\n", cs->rotation);
         s->config.rotation = cs->rotation;
         s->config.priority = cs->priority;
         free(s->config.relative.to);
@@ -583,8 +584,10 @@ _screens_fingerprint(E_Randr2 *r)
              eina_strbuf_append(buf, ":");
              eina_strbuf_append(buf, s->id);
              eina_strbuf_append(buf, ":");
-             if (s->info.lid_closed) eina_strbuf_append(buf, ":LC:");
-             else eina_strbuf_append(buf, ":LO:");
+// Don't do this asbecause this forces a screen replug when you open and
+// close your laptop lid and if that is the only thing you open or close...
+//             if (s->info.lid_closed) eina_strbuf_append(buf, ":LC:");
+//             else eina_strbuf_append(buf, ":LO:");
           }
      }
    str = eina_strbuf_string_steal(buf);
@@ -599,6 +602,7 @@ _screens_differ(E_Randr2 *r1, E_Randr2 *r2)
    Eina_Bool changed = EINA_FALSE;
    Eina_List *l, *ll;
    E_Randr2_Screen *s, *ss;
+   int r1_screen_num = 0, r2_screen_num = 0;
 
    // check monitor outputs and edids, plugged in things
    s1 = _screens_fingerprint(r1);
@@ -610,6 +614,26 @@ _screens_differ(E_Randr2 *r1, E_Randr2 *r2)
    free(s1);
    free(s2);
    // check screen config
+   printf("RRR: screens lists %i -> %i\n", eina_list_count(r1->screens), eina_list_count(r2->screens));
+   printf("RRR: --------\n");
+   EINA_LIST_FOREACH(r1->screens, l, s)
+     {
+        if (!s->id) continue;
+        if ((s->info.connected) &&
+            (!((s->info.is_lid) && (s->info.lid_closed))))
+          r1_screen_num++;
+     }
+   printf("RRR: --------\n");
+   EINA_LIST_FOREACH(r2->screens, l, s)
+     {
+        if (!s->id) continue;
+        if ((s->info.connected) &&
+            (!((s->info.is_lid) && (s->info.lid_closed))))
+          r2_screen_num++;
+     }
+   printf("RRR: --------\n");
+   printf("RRR: screens %i -> %i\n", r1_screen_num, r2_screen_num);
+   printf("RRR: --------\n");
    EINA_LIST_FOREACH(r2->screens, l, s)
      {
         if (!s->id) continue;
@@ -626,14 +650,62 @@ _screens_differ(E_Randr2 *r1, E_Randr2 *r2)
                  (s->config.mode.w != ss->config.mode.w) ||
                  (s->config.mode.h != ss->config.mode.h) ||
                  (s->config.enabled != ss->config.enabled) ||
-                 (s->config.rotation != ss->config.rotation) ||
-                 (s->info.lid_closed != ss->info.lid_closed))
+                 (s->config.rotation != ss->config.rotation))
           changed = EINA_TRUE;
+        else
+          {
+             if (r1_screen_num != r2_screen_num)
+               {
+                  printf("RRR: do change because screen count changed\n");
+                  changed = EINA_TRUE;
+               }
+             else
+               {
+                  if ((r2_screen_num != 1) &&
+                      (s->info.lid_closed != ss->info.lid_closed))
+                    {
+                       printf("RRR: change because laptop lid open/close and number of screens > 1\n");
+                       changed = EINA_TRUE;
+                    }
+                  else
+                    printf("RRR: skip change because of single laptop lid\n");
+               }
+          }
      }
+   printf("RRR: --------\n");
    printf("RRR: changed = %i\n", changed);
    return changed;
 }
 
+static Eina_Bool
+_cb_deferred_suspend_screen_change(void *data EINA_UNUSED)
+{
+   Eina_List *l;
+   E_Randr2_Screen *s;
+   int lids = 0;
+   int ext_screens = 0;
+
+   EINA_LIST_FOREACH(e_randr2->screens, l, s)
+     {
+        if (s->info.is_lid) lids++;
+        else if ((s->config.enabled) &&
+                 (s->config.geom.w > 0) &&
+                 (s->config.geom.h > 0))
+          ext_screens++;
+     }
+   printf("RRR: =========================== deferred suspend.... %i %i\n", lids, ext_screens);
+   if ((lids > 0) && (ext_screens == 0))
+     {
+        if ((e_config->screensaver_suspend_on_ac) ||
+            (e_powersave_mode_get() > E_POWERSAVE_MODE_LOW))
+          {
+             printf("RRR: =========================== powermd low / suspend on ac");
+             e_sys_action_do(E_SYS_SUSPEND, NULL);
+          }
+     }
+   return EINA_FALSE;
+}
+
 static Eina_Bool
 _cb_screen_change_delay(void *data EINA_UNUSED)
 {
@@ -643,6 +715,11 @@ _cb_screen_change_delay(void *data EINA_UNUSED)
    // if we had a screen plug/unplug etc. event and we shouldnt ignore it...
    if ((event_screen) && (!event_ignore))
      {
+        Eina_List *l;
+        E_Randr2_Screen *s;
+        int lid_screens = 0;
+        int close_lid_screens = 0;
+        int external_screens = 0;
         E_Randr2 *rtemp;
 
         printf("RRR: reconfigure screens due to event...\n");
@@ -659,12 +736,74 @@ _cb_screen_change_delay(void *data EINA_UNUSED)
                          change = EINA_TRUE;
                     }
                }
+             EINA_LIST_FOREACH(rtemp->screens, l, s)
+               {
+//                  if (!s->id) continue;
+                  if (s->info.is_lid)
+                    {
+                       lid_screens++;
+                       if (s->info.lid_closed) close_lid_screens++;
+                    }
+                  else
+                    {
+                       if ((s->info.connected) && (s->config.enabled))
+                         external_screens++;
+                    }
+               }
+             printf("RRR: lids=%i closed=%i ext=%i\n", lid_screens, close_lid_screens, external_screens);
              _info_free(rtemp);
           }
         printf("RRR: change = %i\n", change);
         // we plugged or unplugged some monitor - re-apply config so
         // known screens can be configured
-        if (change) e_randr2_config_apply();
+        if (change)
+          {
+             if ((lid_screens > 0) && (close_lid_screens == lid_screens) &&
+                 (external_screens == 0))
+               {
+                  printf("RRR: skip change with all lids closed and no ext\n");
+                  change = EINA_FALSE;
+                  e_screensaver_now_set(EINA_TRUE);
+                  e_screensaver_attrs_set
+                    (1, e_config->screensaver_blanking,
+                     e_config->screensaver_expose);
+                  e_screensaver_update();
+                  e_dpms_force_update();
+                  e_screensaver_activate();
+                  e_screensaver_eval(EINA_TRUE);
+                  // force dpms...
+               }
+             if ((lid_screens > 0) && (close_lid_screens < lid_screens) &&
+                 (external_screens == 0))
+               {
+                  printf("RRR: skip change with lid screens open and no ext\n");
+                  change = EINA_FALSE;
+                  e_screensaver_now_set(EINA_FALSE);
+                  e_screensaver_attrs_set
+                    (e_config->screensaver_timeout,
+                     e_config->screensaver_blanking,
+                     e_config->screensaver_expose);
+                  e_screensaver_update();
+                  e_dpms_force_update();
+                  e_screensaver_deactivate();
+               }
+             if (change)
+               e_randr2_config_apply();
+          }
+        if (change)
+          {
+             if ((lid_screens > 0) && (close_lid_screens == lid_screens) &&
+                 (external_screens == 0))
+               {
+                  printf("RRR: have all closed laptop screens and no external\n");
+                  if ((e_config->screensaver_suspend_on_ac) ||
+                      (e_powersave_mode_get() > E_POWERSAVE_MODE_LOW))
+                    {
+                       printf("RRR: we should try and suspend now because on ac or suspend on ac is on\n");
+                       ecore_timer_add(1.0, _cb_deferred_suspend_screen_change, NULL);
+                    }
+               }
+          }
      }
    // update screen info after the above apply or due to external changes
    e_randr2_screeninfo_update();
@@ -780,6 +919,7 @@ _config_screen_clone_resolve(E_Config_Randr2 *cfg, const char *id, int *x, int *
           return _config_screen_clone_resolve(cfg, cs->rel_to, x, y);
         return NULL;
      }
+   printf("RRR: resolve clone... [%s]\n", cs->id);
    _screen_config_do(s);
    *x = s->config.geom.x;
    *y = s->config.geom.y;
@@ -845,12 +985,17 @@ _screen_clones_common_sync(Eina_List *clones)
    int d, diff = 0x7fffffff;
 
    // find the base/root/master screen for clones
+   printf("RRR: find base/root for list=%p count=%i\n", clones, eina_list_count(clones));
    EINA_LIST_FOREACH(clones, l, s)
      {
         // simple check - if it doesn't clone something else - then it's
         // the master (doesn't handle missing screens)
-        if (s->config.relative.mode != E_RANDR2_RELATIVE_CLONE)
+        printf("RRR: clone=%p mode=%i\n", s, s->config.relative.mode);
+        if ((s->config.relative.mode != E_RANDR2_RELATIVE_CLONE) &&
+            (s->config.relative.mode != E_RANDR2_RELATIVE_NONE) &&
+            (s->config.relative.mode != E_RANDR2_RELATIVE_UNKNOWN))
           {
+             printf("RRR: got it\n");
              sbase = s;
              break;
           }
@@ -862,6 +1007,7 @@ _screen_clones_common_sync(Eina_List *clones)
         modes = eina_list_append(modes, m);
      }
    // ensure it's configured
+   printf("RRR: clone common sync... %p %p\n", sbase, s);
    _screen_config_do(sbase);
 again:
    // we took all modes in the "master"
@@ -930,6 +1076,7 @@ again:
    s->config.mode.w = mcommon->w;
    s->config.mode.h = mcommon->h;
    s->config.mode.refresh = mcommon->refresh;
+   printf("RRR: clones common sync=%ix%i rotation=%i\n", s->config.mode.w, s->config.mode.h, s->config.rotation);
    if ((s->config.rotation == 0) || (s->config.rotation == 180))
      {
         s->config.geom.w = s->config.mode.w;
@@ -981,6 +1128,7 @@ _screen_config_do(E_Randr2_Screen *s)
      }
    s->config.geom.x = 0;
    s->config.geom.y = 0;
+   printf("RRR: screen config do %ix%i rotation=%i\n", s->config.mode.w, s->config.mode.h, s->config.rotation);
    if ((s->config.rotation == 0) || (s->config.rotation == 180))
      {
         s->config.geom.w = s->config.mode.w;
@@ -1002,6 +1150,7 @@ _screen_config_do(E_Randr2_Screen *s)
              s->config.geom.h = s2->config.geom.h;
              s->config.mode.w = s2->config.mode.w;
              s->config.mode.h = s2->config.mode.h;
+             printf("RRR: screen config do rotation=%i\n", s2->config.rotation);
              s->config.rotation = s2->config.rotation;
              s->config.mode.refresh = s2->config.mode.refresh;
           }
@@ -1055,6 +1204,7 @@ _screen_config_do(E_Randr2_Screen *s)
                   s->config.geom.y = y;
                   s->config.mode.w = cs->mode_w;
                   s->config.mode.h = cs->mode_h;
+                  printf("RRR: clone cs rotation=%i\n", cs->rotation);
                   s->config.rotation = cs->rotation;
                   s->config.mode.refresh = cs->mode_refresh;
                   if ((cs->rotation == 0) || (cs->rotation == 180))
@@ -1080,15 +1230,20 @@ _screen_config_eval(void)
    E_Randr2_Screen *s;
    int minx, miny, maxx, maxy;
 
+   printf("RRR:--------------------------------1\n");
    EINA_LIST_FOREACH(e_randr2->screens, l, s)
      {
-        if (s->config.configured) _screen_config_do(s);
+        if (s->config.configured)
+          {
+             printf("RRR: screen config eval this...\n");
+             _screen_config_do(s);
+          }
      }
    minx = 65535;
    miny = 65535;
    maxx = -65536;
    maxy = -65536;
-   printf("RRR:--------------------------------\n");
+   printf("RRR:--------------------------------2\n");
    EINA_LIST_FOREACH(e_randr2->screens, l, s)
      {
         if (!s->config.enabled) continue;
