@@ -313,7 +313,7 @@ struct _Color
 static void
 _e_thumb_generate(E_Thumb *eth)
 {
-   char buf[4096], dbuf[4096], *id, *td, *ext = NULL;
+   char buf[PATH_MAX + 200], dbuf[PATH_MAX + 2], *id, *td, *ext = NULL;
    Evas *evas = NULL, *evas_im = NULL;
    Ecore_Evas *ee = NULL, *ee_im = NULL;
    Evas_Object *im = NULL, *edje = NULL;
