@@ -27,7 +27,7 @@ struct _Settings_Manager
    Ecore_Timer   *timer_retry;
    unsigned long  serial;
    Ecore_X_Atom   _atom_xsettings_screen;
-   Eina_Bool enabled : 1;
+   Eina_Bool enabled E_BITFIELD;
 };
 
 struct _Setting
@@ -353,7 +353,7 @@ _e_xsettings_apply(Settings_Manager *sm)
    pos = data = calloc(1, len);
    if (!data) return;
 
-#if (__BYTE_ORDER == __LITTLE_ENDIAN) || (__BYTE_ORDER__ == __ORDER_LITTLE_ENDIAN__)
+#if (defined __BYTE_ORDER && __BYTE_ORDER == __LITTLE_ENDIAN) || (__BYTE_ORDER__ == __ORDER_LITTLE_ENDIAN__)
    *pos = 0; //LSBFirst
 #else
    *pos = 1; //MSBFirst
@@ -574,7 +574,7 @@ static void
 _e_xsettings_cursor_path_set(void)
 {
    struct stat st;
-   char buf[PATH_MAX], env[4096], *path;
+   char buf[PATH_MAX], env[PATH_MAX + PATH_MAX + 100], *path;
 
    e_user_homedir_concat_static(buf, ".icons");
 
