@@ -519,6 +519,10 @@ _basic_apply(E_Config_Dialog *cfd, E_Config_Dialog_Data *cfdata)
    E_Config_Wallpaper *cw;
 
    if (!cfdata->bg) return 0;
+
+   if (cfdata->all_this_desk_screen != 0)
+     return _adv_apply(cfd, cfdata);
+
    cw = cfd->data;
    if ((!eina_str_has_extension(cfdata->bg, ".edj")) &&
        (!eina_str_has_extension(cfdata->bg, ".gif")) &&
