@@ -1278,7 +1278,7 @@ _evry_selector_thumb_gen(void *data, Evas_Object *obj EINA_UNUSED, void *event_i
      }
 
    e_icon_size_get(sel->o_thumb, &w, &h);
-   edje_extern_object_aspect_set(sel->o_thumb, EDJE_ASPECT_CONTROL_BOTH, w, h);
+   evas_object_size_hint_aspect_set(sel->o_thumb, EVAS_ASPECT_CONTROL_BOTH, w, h);
 
    snprintf(buf, sizeof(buf), "%s:e.swallow.thumb", sel->edje_part);
    edje_object_part_swallow(win->o_main, buf, sel->o_thumb);
@@ -1512,7 +1512,7 @@ _evry_state_new(Evry_Selector *sel, Eina_List *plugins)
 
    if (!s) return NULL;
 
-   s->inp = malloc(INPUTLEN);
+   s->inp = calloc(1, INPUTLEN);
    s->inp[0] = 0;
    s->input = s->inp;
    s->plugins = plugins;
@@ -1891,6 +1891,11 @@ _evry_input_complete(Evry_State *s)
      {
         strncpy(s->input, input, INPUTLEN - 1);
         _evry_update_text_label(s);
+        if (CUR_SEL->update_timer)
+          {
+             ecore_timer_del(CUR_SEL->update_timer);
+             CUR_SEL->update_timer = NULL;
+          }
         _evry_cb_update_timer(CUR_SEL);
         evry_item_select(s, it);
      }
