@@ -63,13 +63,13 @@ struct _Item
    Evas_Object *obj;
    Evas_Coord   x, y, w, h;
    Evas_Object *frame, *image, *thumb;
-   Eina_Bool    selected : 1;
-   Eina_Bool    have_thumb : 1;
-   Eina_Bool    do_thumb : 1;
-   Eina_Bool    get_thumb : 1;
-   Eina_Bool    showing : 1;
-   Eina_Bool    visible : 1;
-   Eina_Bool    changed : 1;
+   Eina_Bool    selected E_BITFIELD;
+   Eina_Bool    have_thumb E_BITFIELD;
+   Eina_Bool    do_thumb E_BITFIELD;
+   Eina_Bool    get_thumb E_BITFIELD;
+   Eina_Bool    showing E_BITFIELD;
+   Eina_Bool    visible E_BITFIELD;
+   Eina_Bool    changed E_BITFIELD;
    int          pos;
    int          max_w, max_h;
 };
@@ -90,7 +90,7 @@ _cb_thumb_gen(void *data, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UN
    if (!it->frame) return;
 
    e_icon_size_get(it->thumb, &w, &h);
-   edje_extern_object_aspect_set(it->thumb, EDJE_ASPECT_CONTROL_BOTH, w, h);
+   evas_object_size_hint_aspect_set(it->thumb, EVAS_ASPECT_CONTROL_BOTH, w, h);
    evas_object_size_hint_max_set(it->thumb, w, h);
    edje_object_part_unswallow(it->frame, it->image);
    edje_object_part_swallow(it->frame, "e.swallow.thumb", it->thumb);
