@@ -145,7 +145,18 @@ _grid_icon_mouse_down(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNU
    Icon *ic = data;
    Evas_Event_Mouse_Up *ev = event_data;
 
-   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return;
+   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD)
+     {
+        if (ev->button == 1)
+          {
+             ic->drag.start = 0;
+             ic->drag.dnd = 0;
+             E_FREE_FUNC(ic->mouse_in_timer, ecore_timer_del);
+             E_FREE_FUNC(ic->mouse_out_timer, ecore_timer_del);
+             E_FREE_FUNC(ic->drag_timer, ecore_timer_del);
+          }
+        return;
+     }
    if (_grid_check_modifiers(ev->modifiers)) return;
 
    if (ev->button == 1)
@@ -155,10 +166,6 @@ _grid_icon_mouse_down(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNU
         E_FREE_FUNC(ic->drag_timer, ecore_timer_del);
         ic->drag_timer = ecore_timer_loop_add(.35, _grid_drag_timer, ic);
      }
-   if (ev->button == 3)
-     {
-        e_gadget_configure(ic->inst->o_main);
-     }
 }
 
 static void
@@ -216,7 +223,8 @@ _grid_icon_mouse_in(void *data, Evas *e EINA_UNUSED, Evas_Object *obj, void *eve
    if (_grid_check_modifiers(ev->modifiers)) return;
 
    evas_object_raise(ic->o_layout);
-   elm_object_tooltip_show(obj);
+   if (!ic->inst->cfg->hide_tooltips)
+     elm_object_tooltip_show(obj);
    ic->active = EINA_TRUE;
    elm_layout_signal_emit(ic->o_layout, "e,state,focused", "e");
 }
@@ -226,7 +234,8 @@ _grid_icon_mouse_out(void *data, Evas *e EINA_UNUSED, Evas_Object *obj, void *ev
 {
    Icon *ic = data;
 
-   elm_object_tooltip_hide(obj);
+   if (!ic->inst->cfg->hide_tooltips)
+     elm_object_tooltip_hide(obj);
    elm_layout_signal_emit(ic->o_layout, "e,state,unfocused", "e");
 }
 
@@ -341,9 +350,12 @@ _grid_icon_add(Instance *inst, Efreet_Desktop *desktop)
 
    _grid_icon_file_set(ic, desktop);
 
-   elm_object_tooltip_text_set(ic->o_icon, desktop->name);
-   elm_object_tooltip_orient_set(ic->o_icon, ELM_TOOLTIP_ORIENT_CENTER);
-   elm_object_tooltip_style_set(ic->o_icon, "luncher");
+   if (!inst->cfg->hide_tooltips)
+     {
+        elm_object_tooltip_text_set(ic->o_icon, desktop->name);
+        elm_object_tooltip_orient_set(ic->o_icon, ELM_TOOLTIP_ORIENT_CENTER);
+        elm_object_tooltip_style_set(ic->o_icon, "luncher");
+     }
    evas_object_size_hint_aspect_set(ic->o_icon, EVAS_ASPECT_CONTROL_BOTH, 1, 1);
    elm_layout_content_set(ic->o_layout, "e.swallow.icon", ic->o_icon);
    evas_object_event_callback_add(ic->o_icon, EVAS_CALLBACK_MOUSE_UP,
