@@ -27,7 +27,7 @@ typedef struct _Context
    Ecore_Timer *connect;
    int default_sink;
 
-   Eina_List *sinks, *sources, *inputs;
+   Eina_List *sinks, *sources, *inputs, *cards;
    Eina_Bool connected;
 } Context;
 
@@ -50,44 +50,56 @@ typedef struct _Source
    int idx;
 } Source;
 
+typedef struct _Profile
+{
+   Emix_Profile base;
+   uint32_t priority;
+} Profile;
+
+typedef struct _Card
+{
+   Emix_Card base;
+   int idx;
+} Card;
+
 static Context *ctx = NULL;
 extern pa_mainloop_api functable;
 
 static pa_cvolume
-_emix_volume_convert(const Emix_Volume volume)
+_emix_volume_convert(const Emix_Volume *volume)
 {
    pa_cvolume vol;
    unsigned int i;
 
-   vol.channels = volume.channel_count;
-   for (i = 0; i < volume.channel_count; i++)
-     vol.values[i] = INT_TO_PA_VOLUME(volume.volumes[i]);
+   vol.channels = volume->channel_count;
+   for (i = 0; i < volume->channel_count; i++)
+     vol.values[i] = INT_TO_PA_VOLUME(volume->volumes[i]);
    return vol;
 }
 
-static Emix_Volume
-_pa_cvolume_convert(const pa_cvolume *volume)
+static void
+_pa_cvolume_convert(const pa_cvolume *volume, Emix_Volume *vol)
 {
-   Emix_Volume vol;
    int i;
 
-   vol.volumes = calloc(volume->channels, sizeof(int));
-   if (!vol.volumes)
+   if (vol->volumes) free(vol->volumes);
+   vol->volumes = calloc(volume->channels, sizeof(int));
+   if (!vol->volumes)
      {
         WRN("Could not allocate memory for volume");
-        vol.channel_count = 0;
-        return vol;
+        vol->channel_count = 0;
+        return;
      }
 
-   vol.channel_count = volume->channels;
+   vol->channel_count = volume->channels;
    for (i = 0; i < volume->channels; i++)
-     vol.volumes[i] = PA_VOLUME_TO_INT(volume->values[i]);
-   return vol;
+     vol->volumes[i] = PA_VOLUME_TO_INT(volume->values[i]);
 }
 
 static void
 _sink_del(Sink *sink)
 {
+   unsigned int i;
    Emix_Port *port;
 
    EINA_SAFETY_ON_NULL_RETURN(sink);
@@ -99,6 +111,9 @@ _sink_del(Sink *sink)
      }
 
    free(sink->base.volume.volumes);
+   for(i = 0; i < sink->base.volume.channel_count; ++i)
+     eina_stringshare_del(sink->base.volume.channel_names[i]);
+   free(sink->base.volume.channel_names);
    eina_stringshare_del(sink->base.name);
    free(sink);
 }
@@ -106,9 +121,13 @@ _sink_del(Sink *sink)
 static void
 _sink_input_del(Sink_Input *input)
 {
+   unsigned int i;
    EINA_SAFETY_ON_NULL_RETURN(input);
 
    free(input->base.volume.volumes);
+   for(i = 0; i < input->base.volume.channel_count; ++i)
+     eina_stringshare_del(input->base.volume.channel_names[i]);
+   free(input->base.volume.channel_names);
    eina_stringshare_del(input->base.name);
    eina_stringshare_del(input->icon);
    free(input);
@@ -117,13 +136,33 @@ _sink_input_del(Sink_Input *input)
 static void
 _source_del(Source *source)
 {
+   unsigned int i;
    EINA_SAFETY_ON_NULL_RETURN(source);
 
    free(source->base.volume.volumes);
+   for(i = 0; i < source->base.volume.channel_count; ++i)
+     eina_stringshare_del(source->base.volume.channel_names[i]);
+   free(source->base.volume.channel_names);
    eina_stringshare_del(source->base.name);
    free(source);
 }
 
+static void
+_card_del(Card *card)
+{
+   Profile *profile;
+   EINA_SAFETY_ON_NULL_RETURN(card);
+
+   EINA_LIST_FREE(card->base.profiles, profile)
+     {
+        eina_stringshare_del(profile->base.name);
+        eina_stringshare_del(profile->base.description);
+        free(profile);
+     }
+   eina_stringshare_del(card->base.name);
+   free(card);
+}
+
 static void
 _sink_cb(pa_context *c EINA_UNUSED, const pa_sink_info *info, int eol,
          void *userdata EINA_UNUSED)
@@ -150,7 +189,10 @@ _sink_cb(pa_context *c EINA_UNUSED, const pa_sink_info *info, int eol,
    sink = calloc(1, sizeof(Sink));
    sink->idx = info->index;
    sink->base.name = eina_stringshare_add(info->description);
-   sink->base.volume = _pa_cvolume_convert(&info->volume);
+   _pa_cvolume_convert(&info->volume, &sink->base.volume);
+   sink->base.volume.channel_names = calloc(sink->base.volume.channel_count, sizeof(Emix_Channel));
+   for (i = 0; i < sink->base.volume.channel_count; ++i)
+     sink->base.volume.channel_names[i] = eina_stringshare_add(pa_channel_position_to_pretty_string(info->channel_map.map[i]));
    sink->base.mute = !!info->mute;
 
    for (i = 0; i < info->n_ports; i++)
@@ -211,8 +253,19 @@ _sink_changed_cb(pa_context *c EINA_UNUSED, const pa_sink_info *info, int eol,
 
    EINA_SAFETY_ON_NULL_RETURN(sink);
 
-   sink->base.name = eina_stringshare_add(info->description);
-   sink->base.volume = _pa_cvolume_convert(&info->volume);
+   eina_stringshare_replace(&sink->base.name, info->description);
+
+   if (sink->base.volume.channel_count != info->volume.channels)
+     {
+        for (i = 0; i < sink->base.volume.channel_count; ++i)
+          eina_stringshare_del(sink->base.volume.channel_names[i]);
+        free(sink->base.volume.channel_names);
+        sink->base.volume.channel_names = calloc(info->volume.channels, sizeof(Emix_Channel));
+     }
+   _pa_cvolume_convert(&info->volume, &sink->base.volume);
+   for (i = 0; i < sink->base.volume.channel_count; ++i)
+     eina_stringshare_replace(&sink->base.volume.channel_names[i],
+                              pa_channel_position_to_pretty_string(info->channel_map.map[i]));
    sink->base.mute = !!info->mute;
 
    if (sink->base.ports)
@@ -309,6 +362,7 @@ _sink_input_cb(pa_context *c EINA_UNUSED, const pa_sink_input_info *info,
    Eina_List *l;
    Sink *s;
    const char *t;
+   unsigned int i;
    EINA_SAFETY_ON_NULL_RETURN(ctx);
 
    if (eol < 0)
@@ -347,7 +401,10 @@ _sink_input_cb(pa_context *c EINA_UNUSED, const pa_sink_input_info *info,
      }
    input->base.name = eina_stringshare_add(eina_strbuf_string_get(input_name));
    eina_strbuf_free(input_name);
-   input->base.volume = _pa_cvolume_convert(&info->volume);
+   _pa_cvolume_convert(&info->volume, &input->base.volume);
+   input->base.volume.channel_names = calloc(input->base.volume.channel_count, sizeof(Emix_Channel));
+   for (i = 0; i < input->base.volume.channel_count; ++i)
+     input->base.volume.channel_names[i] = eina_stringshare_add(pa_channel_position_to_pretty_string(info->channel_map.map[i]));
    input->base.mute = !!info->mute;
    EINA_LIST_FOREACH(ctx->sinks, l, s)
      {
@@ -372,10 +429,11 @@ _sink_input_changed_cb(pa_context *c EINA_UNUSED,
                        const pa_sink_input_info *info, int eol,
                        void *userdata EINA_UNUSED)
 {
-   Sink_Input *input = NULL, *i;
+   Sink_Input *input = NULL, *si;
    Sink *s = NULL;
    Eina_List *l;
    const char *t;
+   unsigned int i;
 
    EINA_SAFETY_ON_NULL_RETURN(ctx);
    if (eol < 0)
@@ -390,11 +448,11 @@ _sink_input_changed_cb(pa_context *c EINA_UNUSED,
    if (eol > 0)
       return;
 
-   EINA_LIST_FOREACH(ctx->inputs, l, i)
+   EINA_LIST_FOREACH(ctx->inputs, l, si)
      {
-        if (i->idx == (int)info->index)
+        if (si->idx == (int)info->index)
           {
-            input = i;
+            input = si;
             break;
           }
      }
@@ -408,7 +466,18 @@ _sink_input_changed_cb(pa_context *c EINA_UNUSED,
         ctx->inputs = eina_list_append(ctx->inputs, input);
      }
    input->idx = info->index;
-   input->base.volume = _pa_cvolume_convert(&info->volume);
+   if (input->base.volume.channel_count != info->volume.channels)
+     {
+        for (i = 0; i < input->base.volume.channel_count; ++i)
+          eina_stringshare_del(input->base.volume.channel_names[i]);
+        free(input->base.volume.channel_names);
+        input->base.volume.channel_names = calloc(info->volume.channels, sizeof(Emix_Channel));
+     }
+   _pa_cvolume_convert(&info->volume, &input->base.volume);
+   for (i = 0; i < input->base.volume.channel_count; ++i)
+     eina_stringshare_replace(&input->base.volume.channel_names[i],
+                              pa_channel_position_to_pretty_string(info->channel_map.map[i]));
+
    input->base.mute = !!info->mute;
 
    EINA_LIST_FOREACH(ctx->sinks, l, s)
@@ -456,6 +525,7 @@ _source_cb(pa_context *c EINA_UNUSED, const pa_source_info *info,
            int eol, void *userdata EINA_UNUSED)
 {
    Source *source;
+   unsigned int i;
    EINA_SAFETY_ON_NULL_RETURN(ctx);
 
    if (eol < 0)
@@ -475,7 +545,10 @@ _source_cb(pa_context *c EINA_UNUSED, const pa_source_info *info,
 
    source->idx = info->index;
    source->base.name = eina_stringshare_add(info->name);
-   source->base.volume = _pa_cvolume_convert(&info->volume);
+   _pa_cvolume_convert(&info->volume, &source->base.volume);
+   source->base.volume.channel_names = calloc(source->base.volume.channel_count, sizeof(Emix_Channel));
+   for (i = 0; i < source->base.volume.channel_count; ++i)
+     source->base.volume.channel_names[i] = eina_stringshare_add(pa_channel_position_to_pretty_string(info->channel_map.map[i]));
    source->base.mute = !!info->mute;
 
    ctx->sources = eina_list_append(ctx->sources, source);
@@ -491,6 +564,7 @@ _source_changed_cb(pa_context *c EINA_UNUSED,
 {
    Source *source = NULL, *s;
    Eina_List *l;
+   unsigned int i;
    EINA_SAFETY_ON_NULL_RETURN(ctx);
 
    if (eol < 0)
@@ -523,7 +597,17 @@ _source_changed_cb(pa_context *c EINA_UNUSED,
         ctx->sources = eina_list_append(ctx->sources, source);
      }
    source->idx= info->index;
-   source->base.volume = _pa_cvolume_convert(&info->volume);
+   if (source->base.volume.channel_count != info->volume.channels)
+     {
+        for (i = 0; i < source->base.volume.channel_count; ++i)
+          eina_stringshare_del(source->base.volume.channel_names[i]);
+        free(source->base.volume.channel_names);
+        source->base.volume.channel_names = calloc(info->volume.channels, sizeof(Emix_Channel));
+     }
+   _pa_cvolume_convert(&info->volume, &source->base.volume);
+   for (i = 0; i < source->base.volume.channel_count; ++i)
+     eina_stringshare_replace(&source->base.volume.channel_names[i],
+                              pa_channel_position_to_pretty_string(info->channel_map.map[i]));
    source->base.mute = !!info->mute;
 
    if (ctx->cb)
@@ -602,6 +686,179 @@ _server_info_cb(pa_context *c, const pa_server_info *info,
    pa_operation_unref(o);
 }
 
+static int
+_profile_sort_cb(const Profile *p1, const Profile *p2)
+{
+   if (p1->priority < p2->priority) return 1;
+   if (p1->priority > p2->priority) return -1;
+   return 0;
+}
+
+static void
+_card_cb(pa_context *c, const pa_card_info *info, int eol, void *userdata EINA_UNUSED)
+{
+     Card *card;
+     const char *description;
+     uint32_t i, j;
+     Profile *profile;
+
+     if (eol < 0) {
+          if (pa_context_errno(c) == PA_ERR_NOENTITY)
+            return;
+
+          ERR("Card callback failure: %d", pa_context_errno(c));
+          return;
+     }
+   if (eol > 0)
+      return;
+
+   card = calloc(1, sizeof(Card));
+   EINA_SAFETY_ON_NULL_RETURN(card);
+
+   card->idx = info->index;
+
+   description = pa_proplist_gets(info->proplist, PA_PROP_DEVICE_DESCRIPTION);
+   card->base.name = description
+      ? eina_stringshare_add(description)
+      : eina_stringshare_add(info->name);
+
+   for (i = 0; i < info->n_ports; ++i)
+     {
+        for (j = 0; j < info->ports[i]->n_profiles; ++j)
+          {
+             profile = calloc(1, sizeof(Profile));
+             profile->base.name = eina_stringshare_add(info->ports[i]->profiles[j]->name);
+             profile->base.description = eina_stringshare_add(info->ports[i]->profiles[j]->description);
+             profile->priority = info->ports[i]->profiles[j]->priority;
+             if ((info->ports[i]->available == PA_PORT_AVAILABLE_NO)
+               && ((strcmp("analog-output-speaker", profile->base.name))
+                   || (strcmp("analog-input-microphone-internal", profile->base.name))))
+                  profile->base.plugged = EINA_FALSE;
+             else
+               profile->base.plugged = EINA_TRUE;
+
+             if (info->active_profile)
+               {
+                  if (info->ports[i]->profiles[j]->name == info->active_profile->name)
+                    profile->base.active = EINA_TRUE;
+               }
+             card->base.profiles =
+                eina_list_sorted_insert(card->base.profiles,
+                                        (Eina_Compare_Cb)_profile_sort_cb,
+                                        profile);
+          }
+     }
+   ctx->cards = eina_list_append(ctx->cards, card);
+   if (ctx->cb)
+     ctx->cb((void *)ctx->userdata, EMIX_CARD_ADDED_EVENT,
+             (Emix_Card *)card);
+}
+
+static void
+_card_changed_cb(pa_context *c EINA_UNUSED, const pa_card_info *info, int eol,
+                 void *userdata EINA_UNUSED)
+{
+   Card *card = NULL, *ca;
+   Eina_List *l;
+   const char *description;
+   uint32_t i, j;
+   Profile *profile;
+
+   if (eol < 0)
+     {
+        if (pa_context_errno(c) == PA_ERR_NOENTITY)
+           return;
+
+        ERR("Card callback failure");
+        return;
+     }
+
+   if (eol > 0)
+      return;
+
+   DBG("card index: %d\n", info->index);
+
+   EINA_LIST_FOREACH(ctx->cards, l, ca)
+     {
+        if (ca->idx == (int)info->index)
+          {
+             card = ca;
+             break;
+          }
+     }
+
+   EINA_SAFETY_ON_NULL_RETURN(card);
+
+   description = pa_proplist_gets(info->proplist, PA_PROP_DEVICE_DESCRIPTION);
+   eina_stringshare_replace(&card->base.name,
+                            (description
+                             ? eina_stringshare_add(description)
+                             : eina_stringshare_add(info->name)));
+
+   EINA_LIST_FREE(card->base.profiles, profile)
+     {
+        eina_stringshare_del(profile->base.name);
+        eina_stringshare_del(profile->base.description);
+        free(profile);
+     }
+   for (i = 0; i < info->n_ports; ++i)
+     {
+        for (j = 0; j < info->ports[i]->n_profiles; ++j)
+          {
+             profile = calloc(1, sizeof(Profile));
+             profile->base.name = eina_stringshare_add(info->ports[i]->profiles[j]->name);
+             profile->base.description = eina_stringshare_add(info->ports[i]->profiles[j]->description);
+             profile->priority = info->ports[i]->profiles[j]->priority;
+             if ((info->ports[i]->available == PA_PORT_AVAILABLE_NO)
+               && ((strcmp("analog-output-speaker", profile->base.name))
+                   || (strcmp("analog-input-microphone-internal", profile->base.name))))
+                  profile->base.plugged = EINA_FALSE;
+             else
+               profile->base.plugged = EINA_TRUE;
+
+             if (info->active_profile)
+               {
+                  if (info->ports[i]->profiles[j]->name == info->active_profile->name)
+                    profile->base.active = EINA_TRUE;
+               }
+             card->base.profiles =
+                eina_list_sorted_insert(card->base.profiles,
+                                        (Eina_Compare_Cb)_profile_sort_cb,
+                                        profile);
+          }
+     }
+
+   if (ctx->cb)
+     ctx->cb((void *)ctx->userdata, EMIX_CARD_CHANGED_EVENT,
+                  (Emix_Card *)card);
+}
+
+static void
+_card_remove_cb(int index, void *data EINA_UNUSED)
+{
+   Card *card;
+   Eina_List *l;
+   EINA_SAFETY_ON_NULL_RETURN(ctx);
+
+   DBG("Removing card: %d", index);
+
+   EINA_LIST_FOREACH(ctx->cards, l, card)
+     {
+        if (card->idx == index)
+          {
+             ctx->cards = eina_list_remove_list(ctx->cards, l);
+             if (ctx->cb)
+               ctx->cb((void *)ctx->userdata,
+                       EMIX_CARD_REMOVED_EVENT,
+                       (Emix_Card *)card);
+             _card_del(card);
+
+             break;
+          }
+     }
+}
+
+
 static void
 _subscribe_cb(pa_context *c, pa_subscription_event_type_t t,
               uint32_t index, void *data)
@@ -701,6 +958,34 @@ _subscribe_cb(pa_context *c, pa_subscription_event_type_t t,
          }
        pa_operation_unref(o);
        break;
+
+    case PA_SUBSCRIPTION_EVENT_CARD:
+       if ((t & PA_SUBSCRIPTION_EVENT_TYPE_MASK) ==
+           PA_SUBSCRIPTION_EVENT_REMOVE)
+           _card_remove_cb(index, data);
+       else if ((t & PA_SUBSCRIPTION_EVENT_TYPE_MASK) ==
+                PA_SUBSCRIPTION_EVENT_NEW)
+         {
+            if (!(o = pa_context_get_card_info_by_index(c, index, _card_cb,
+                                                        data)))
+              {
+                 ERR("pa_context_get_card_info() failed");
+                 return;
+              }
+            pa_operation_unref(o);
+         }
+       else
+         {
+            if (!(o = pa_context_get_card_info_by_index(c, index, _card_changed_cb,
+                                                        data)))
+              {
+                 ERR("pa_context_get_card_info() failed");
+                 return;
+              }
+            pa_operation_unref(o);
+         }
+       break;
+
     default:
        WRN("Event not handled");
        break;
@@ -773,6 +1058,17 @@ _pulse_pa_state_cb(pa_context *context, void *data)
              return;
           }
         pa_operation_unref(o);
+
+        if (!(o = pa_context_get_card_info_list(context, _card_cb,
+                                             ctx)))
+          {
+             ERR("pa_context_get_server_info() failed");
+             return;
+          }
+        pa_operation_unref(o);
+
+
+
         break;
 
       case PA_CONTEXT_FAILED:
@@ -910,6 +1206,7 @@ _disconnect_cb()
    Source *source;
    Sink *sink;
    Sink_Input *input;
+   Card *card;
 
    if (ctx->cb)
       ctx->cb((void *)ctx->userdata, EMIX_DISCONNECTED_EVENT, NULL);
@@ -920,10 +1217,12 @@ _disconnect_cb()
       _sink_del(sink);
    EINA_LIST_FREE(ctx->inputs, input)
       _sink_input_del(input);
+   EINA_LIST_FREE(ctx->cards, card)
+      _card_del(card);
 }
 
 static void
-_source_volume_set(Emix_Source *source, Emix_Volume volume)
+_source_volume_set(Emix_Source *source, Emix_Volume *volume)
 {
    pa_operation* o;
    pa_cvolume vol = _emix_volume_convert(volume);
@@ -970,7 +1269,7 @@ _sink_inputs_get(void)
 }
 
 static void
-_sink_volume_set(Emix_Sink *sink, Emix_Volume volume)
+_sink_volume_set(Emix_Sink *sink, Emix_Volume *volume)
 {
    pa_operation* o;
    Sink *s = (Sink *)sink;
@@ -995,7 +1294,7 @@ _sink_mute_set(Emix_Sink *sink, Eina_Bool mute)
 }
 
 static void
-_sink_input_volume_set(Emix_Sink_Input *input, Emix_Volume volume)
+_sink_input_volume_set(Emix_Sink_Input *input, Emix_Volume *volume)
 {
    pa_operation* o;
    Sink_Input *sink_input = (Sink_Input *)input;
@@ -1089,6 +1388,34 @@ _max_volume(void)
    return 150;
 }
 
+static const Eina_List *
+_cards_get(void)
+{
+   EINA_SAFETY_ON_NULL_RETURN_VAL(ctx, NULL);
+   return ctx->cards;
+}
+
+static Eina_Bool
+_card_profile_set(Emix_Card *card, const Emix_Profile *profile)
+{
+   pa_operation* o;
+   Card *c = (Card *)card;
+   Profile *p = (Profile *)profile;
+   EINA_SAFETY_ON_FALSE_RETURN_VAL(ctx && ctx->context &&
+                                   (c != NULL) && (p != NULL), EINA_FALSE);
+
+   if (!(o = pa_context_set_card_profile_by_index(ctx->context,
+                                                  c->idx, p->base.name, NULL,
+                                                  NULL)))
+     {
+        ERR("pa_context_set_card_profile_by_index() failed");
+        return EINA_FALSE;
+     }
+   pa_operation_unref(o);
+
+   return EINA_TRUE;
+}
+
 static Emix_Backend
 _pulseaudio_backend =
 {
@@ -1111,6 +1438,8 @@ _pulseaudio_backend =
    _source_mute_set,
    _source_volume_set,
    NULL,
+   _cards_get,
+   _card_profile_set
 };
 
 E_API Emix_Backend *
