@@ -45,13 +45,13 @@ struct _Pager
    int             xnum, ynum;
    Eina_List      *desks;
    Pager_Desk     *active_pd;
-   unsigned char   dragging : 1;
-   unsigned char   just_dragged : 1;
+   unsigned char   dragging E_BITFIELD;
+   unsigned char   just_dragged E_BITFIELD;
    Evas_Coord      dnd_x, dnd_y;
    Pager_Desk     *active_drop_pd;
    E_Client       *active_drag_client;
    Ecore_Job      *recalc;
-   Eina_Bool       invert : 1;
+   Eina_Bool       invert E_BITFIELD;
 };
 
 struct _Pager_Desk
@@ -62,12 +62,12 @@ struct _Pager_Desk
    Evas_Object *o_desk;
    Evas_Object *o_layout;
    int          xpos, ypos, urgent;
-   int          current : 1;
+   int          current E_BITFIELD;
    struct
    {
       Pager        *from_pager;
-      unsigned char in_pager : 1;
-      unsigned char start : 1;
+      unsigned char in_pager E_BITFIELD;
+      unsigned char start E_BITFIELD;
       int           x, y, dx, dy, button;
    } drag;
 };
@@ -78,13 +78,13 @@ struct _Pager_Win
    Pager_Desk   *desk;
    Evas_Object  *o_window;
    Evas_Object  *o_mirror;
-   unsigned char skip_winlist : 1;
+   unsigned char skip_winlist E_BITFIELD;
    struct
    {
       Pager        *from_pager;
-      unsigned char start : 1;
-      unsigned char in_pager : 1;
-      unsigned char desktop  : 1;
+      unsigned char start E_BITFIELD;
+      unsigned char in_pager E_BITFIELD;
+      unsigned char desktop  E_BITFIELD;
       int           x, y, dx, dy, button;
    } drag;
 };
@@ -95,7 +95,7 @@ struct _Pager_Popup
    Evas_Object  *o_bg;
    Pager        *pager;
    Ecore_Timer  *timer;
-   unsigned char urgent : 1;
+   unsigned char urgent E_BITFIELD;
 };
 
 static void             _pager_cb_mirror_add(Pager_Desk *pd, Evas_Object *obj, Evas_Object *mirror);
@@ -603,6 +603,8 @@ _pager_desk_switch(Pager_Desk *pd1, Pager_Desk *pd2)
         pw->client->hidden = 0;
         e_client_desk_set(pw->client, desk1);
      }
+   e_deskmirror_update_force(pd1->o_layout);
+   e_deskmirror_update_force(pd2->o_layout);
 
    /* Modify desktop names in the config */
    for (l = e_config->desktop_names, c = 0; l && c < 2; l = l->next)
@@ -755,7 +757,7 @@ _pager_popup_new(E_Zone *zone, int keyaction)
    /* Show popup */
 
    pp->pager = _pager_new(e_comp->evas, zone, NULL);
-   
+
    pp->pager->popup = pp;
    pp->urgent = 0;
 
@@ -1162,8 +1164,6 @@ _pager_window_cb_mouse_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EI
    Evas_Coord x, y, w, h;
    const char *drag_types[] =
    { "enlightenment/pager_win", "enlightenment/border" };
-   Evas_Coord dx, dy;
-   unsigned int resist = 0;
 
    ev = event_info;
    pw = data;
@@ -1176,13 +1176,8 @@ _pager_window_cb_mouse_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EI
    /* prevent drag for a few pixels */
    if (!pw->drag.start) return;
 
-   dx = pw->drag.x - ev->cur.output.x;
-   dy = pw->drag.y - ev->cur.output.y;
-   if (pw->desk->pager)
-     resist = pager_config->drag_resist;
-
-   if (((unsigned int)(dx * dx) + (unsigned int)(dy * dy)) <=
-       (resist * resist)) return;
+   if (!is_dragged(pw->drag.x - ev->cur.output.x,
+                   pw->drag.y - ev->cur.output.y)) return;
 
    pw->desk->pager->dragging = 1;
    pw->drag.start = 0;
@@ -1198,6 +1193,7 @@ _pager_window_cb_mouse_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EI
                      _pager_window_cb_drag_finished);
    drag->button_mask = evas_pointer_button_down_mask_get(e_comp->evas);
 
+   evas_object_raise(pw->client->frame);
    /* this is independent of the original mirror */
    o = e_deskmirror_mirror_copy(pw->o_mirror);
    evas_object_show(o);
@@ -1236,6 +1232,7 @@ _pager_window_cb_drag_finished(E_Drag *drag, int dropped)
         /* be helpful */
         if (pw->client->desk->visible && (!e_client_focused_get()))
           evas_object_focus_set(pw->client->frame, 1);
+        e_deskmirror_update_force(pw->desk->o_layout);
      }
    else
      {
@@ -1271,6 +1268,7 @@ _pager_window_cb_drag_finished(E_Drag *drag, int dropped)
 
         if (!(ec->lock_user_stacking)) evas_object_raise(ec->frame);
         evas_object_focus_set(ec->frame, 1);
+        e_deskmirror_update_force(pw->desk->o_layout);
      }
    if (p->active_drop_pd)
      {
@@ -1335,10 +1333,11 @@ _pager_update_drop_position(Pager *p, Evas_Coord x, Evas_Coord y)
    if (!pw) return;
    if (pd)
      {
-        int zx, zy, zw, zh, vx, vy;
+        int zx, zy, zw, zh, vx, vy, offx, offy;
         E_Client *ec = pw->client;
         E_Desk *old_desk = ec->desk;
         Eina_Bool was_focused = e_client_stack_focused_get(ec);
+        E_Drag *drag = e_drag_current_get();
 
         pw->drag.in_pager = 1;
         //makes drags look weird
@@ -1346,12 +1345,18 @@ _pager_update_drop_position(Pager *p, Evas_Coord x, Evas_Coord y)
         zx = pd->desk->zone->x, zy = pd->desk->zone->y;
         zw = pd->desk->zone->w, zh = pd->desk->zone->h;
         e_deskmirror_coord_canvas_to_virtual(pd->o_layout,
-                                         x + pw->drag.dx,
-                                         y + pw->drag.dy, &vx, &vy);
+                                             x, y, &vx, &vy);
         ec->hidden = !pd->desk->visible;
         e_client_desk_set(ec, pd->desk);
-        x = E_CLAMP(vx + zx, zx, zx + zw - ec->w);
-        y = E_CLAMP(vy + zy, zy, zy + zh - ec->h);
+        offx = (ec->w / 2);
+        offy = (ec->h / 2);
+        if (drag)
+          {
+             if (drag->w > 0) offx = ((drag->dx) * ec->w) / drag->w;
+             if (drag->h > 0) offy = ((drag->dy) * ec->h) / drag->h;
+          }
+        x = E_CLAMP(vx + zx - offx, zx, zx + zw - ec->w);
+        y = E_CLAMP(vy + zy - offy, zy, zy + zh - ec->h);
         evas_object_move(ec->frame, x, y);
         if (was_focused)
           e_desk_last_focused_focus(old_desk);
@@ -1420,7 +1425,6 @@ _pager_drop_cb_drop(void *data, const char *type, void *event_info)
    Pager_Desk *pd2 = NULL;
    E_Client *ec = NULL;
    Eina_List *l;
-   int dx = 0, dy = 0;
    Pager_Win *pw = NULL;
    Evas_Coord wx, wy, wx2, wy2;
    Evas_Coord nx, ny;
@@ -1440,19 +1444,15 @@ _pager_drop_cb_drop(void *data, const char *type, void *event_info)
              if (pw)
                {
                   ec = pw->client;
-                  dx = pw->drag.dx;
-                  dy = pw->drag.dy;
                }
           }
         else if (!strcmp(type, "enlightenment/border"))
           {
              ec = ev->data;
              e_deskmirror_coord_virtual_to_canvas(pd->o_layout, ec->x, ec->y,
-                                              &wx, &wy);
+                                                  &wx, &wy);
              e_deskmirror_coord_virtual_to_canvas(pd->o_layout, ec->x + ec->w,
-                                              ec->y + ec->h, &wx2, &wy2);
-             dx = (wx - wx2) / 2;
-             dy = (wy - wy2) / 2;
+                                                  ec->y + ec->h, &wx2, &wy2);
           }
         else if (!strcmp(type, "enlightenment/vdesktop"))
           {
@@ -1483,21 +1483,28 @@ _pager_drop_cb_drop(void *data, const char *type, void *event_info)
 
              if ((!max) && (!fullscreen))
                {
-                  int zx, zy, zw, zh, mx, my;
+                  E_Drag *drag = e_drag_current_get();
+                  int zx, zy, zw, zh, mx, my, offx, offy;
 
                   e_deskmirror_coord_canvas_to_virtual(pd->o_layout,
-                                                   ev->x + dx,
-                                                   ev->y + dy,
-                                                   &nx, &ny);
+                                                       ev->x, ev->y,
+                                                       &nx, &ny);
                   e_zone_useful_geometry_get(pd->desk->zone,
                                              &zx, &zy, &zw, &zh);
-
-                  mx = E_CLAMP(nx + zx, zx, zx + zw - ec->w);
-                  my = E_CLAMP(ny + zy, zy, zy + zh - ec->h);
+                  offx = (ec->w / 2);
+                  offy = (ec->h / 2);
+                  if (drag)
+                    {
+                       if (drag->w > 0) offx = ((drag->dx) * ec->w) / drag->w;
+                       if (drag->h > 0) offy = ((drag->dy) * ec->h) / drag->h;
+                    }
+                  mx = E_CLAMP(nx + zx - offx, zx, zx + zw - ec->w);
+                  my = E_CLAMP(ny + zy - offy, zy, zy + zh - ec->h);
                   evas_object_move(ec->frame, mx, my);
                }
              if (max) e_client_maximize(ec, max);
              if (fullscreen) e_client_fullscreen(ec, fs);
+             e_deskmirror_update_force(pd->o_layout);
           }
      }
 
@@ -1581,8 +1588,6 @@ _pager_desk_cb_mouse_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA
 {
    Evas_Event_Mouse_Move *ev;
    Pager_Desk *pd;
-   Evas_Coord dx, dy;
-   unsigned int resist = 0;
    E_Drag *drag;
    Evas_Object *o;
    Evas_Coord x, y, w, h;
@@ -1595,13 +1600,8 @@ _pager_desk_cb_mouse_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA
    /* prevent drag for a few pixels */
    if (pd->drag.start)
      {
-        dx = pd->drag.x - ev->cur.output.x;
-        dy = pd->drag.y - ev->cur.output.y;
-        if ((pd->pager) && (pd->pager->inst))
-          resist = pager_config->drag_resist;
-
-        if (((unsigned int)(dx * dx) + (unsigned int)(dy * dy)) <=
-            (resist * resist)) return;
+        if (!is_dragged(pd->drag.x - ev->cur.output.x,
+                        pd->drag.y - ev->cur.output.y)) return;
 
         if (pd->pager) pd->pager->dragging = 1;
         pd->drag.start = 0;
@@ -1613,7 +1613,7 @@ _pager_desk_cb_mouse_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA
         drag = e_drag_new(x, y, drag_types, 1, pd, -1,
                           NULL, _pager_desk_cb_drag_finished);
         drag->button_mask = evas_pointer_button_down_mask_get(e_comp->evas);
-        
+
         /* redraw the desktop theme above */
         o = e_comp_object_util_mirror_add(pd->o_layout);
         e_drag_object_set(drag, o);
