@@ -23,12 +23,12 @@ struct _Pager
    int           xnum, ynum;
    Eina_List    *desks;
    Pager_Desk   *active_pd;
-   unsigned char dragging : 1;
-   unsigned char just_dragged : 1;
+   unsigned char dragging E_BITFIELD;
+   unsigned char just_dragged E_BITFIELD;
    E_Client     *active_drag_client;
    Ecore_Job    *recalc;
-   Eina_Bool     invert : 1;
-   Eina_Bool     plain : 1;
+   Eina_Bool     invert E_BITFIELD;
+   Eina_Bool     plain E_BITFIELD;
 };
 
 struct _Pager_Desk
@@ -40,12 +40,12 @@ struct _Pager_Desk
    Evas_Object *o_layout;
    Evas_Object *drop_handler;
    int          xpos, ypos, urgent;
-   int          current : 1;
+   int          current E_BITFIELD;
    struct
    {
       Pager        *from_pager;
-      unsigned char in_pager : 1;
-      unsigned char start : 1;
+      unsigned char in_pager E_BITFIELD;
+      unsigned char start E_BITFIELD;
       int           x, y, dx, dy, button;
    } drag;
 };
@@ -57,13 +57,13 @@ struct _Pager_Win
    Evas_Object  *o_window;
    Evas_Object  *o_mirror;
    Evas_Object  *o_icon;
-   unsigned char skip_winlist : 1;
+   unsigned char skip_winlist E_BITFIELD;
    struct
    {
       Pager        *from_pager;
-      unsigned char start : 1;
-      unsigned char in_pager : 1;
-      unsigned char desktop  : 1;
+      unsigned char start E_BITFIELD;
+      unsigned char in_pager E_BITFIELD;
+      unsigned char desktop  E_BITFIELD;
       int           x, y, dx, dy, button;
    } drag;
 };
@@ -74,14 +74,13 @@ struct _Pager_Popup
    Evas_Object  *o_bg;
    Pager        *pager;
    Ecore_Timer  *timer;
-   unsigned char urgent : 1;
+   unsigned char urgent E_BITFIELD;
 };
 
 static void         _pager_cb_mirror_add(Pager_Desk *pd, Evas_Object *obj, Evas_Object *mirror);
 
 static void         _pager_cb_obj_show(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED);
 static void         _pager_cb_obj_hide(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info EINA_UNUSED);
-static void         _button_cb_mouse_down(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info);
 static Evas_Object *_pager_gadget_configure(Evas_Object *g);
 static Eina_Bool    _pager_cb_event_powersave_change(void *data EINA_UNUSED, int type EINA_UNUSED, void *event);
 static Eina_Bool    _pager_cb_event_desk_show(void *data EINA_UNUSED, int type EINA_UNUSED, void *event);
@@ -783,6 +782,8 @@ _pager_desk_switch(Pager_Desk *pd1, Pager_Desk *pd2)
         pw->client->hidden = 0;
         e_client_desk_set(pw->client, desk1);
      }
+   e_deskmirror_update_force(pd1->o_layout);
+   e_deskmirror_update_force(pd2->o_layout);
 
    /* Modify desktop names in the config */
    for (l = e_config->desktop_names, c = 0; l && c < 2; l = l->next)
@@ -1088,21 +1089,6 @@ _pager_gadget_configure(Evas_Object *g EINA_UNUSED)
    return config_pager(e_zone_current_get());
 }
 
-static void
-_button_cb_mouse_down(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_info)
-{
-   Instance *inst = data;
-   Evas_Event_Mouse_Down *ev = event_info;
-
-   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return;
-   if (_pager_check_modifiers(ev->modifiers)) return;
-   if (ev->button != 3) return;
-   if (!pager_config) return;
-   if (cfg_dialog) return;
-   ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
-   e_gadget_configure(inst->o_pager);
-}
-
 EINTERN void
 _pager_cb_config_gadget_updated(Eina_Bool style_changed)
 {
@@ -2000,12 +1986,15 @@ _pager_window_cb_mouse_up(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA
    Evas_Event_Mouse_Up *ev = event_info;
    Pager_Win *pw = data;
 
-   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return;
+   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD)
+     {
+        pw->drag.button = 0;
+        return;
+     }
+   pw->drag.button = 0;
    if (_pager_check_modifiers(ev->modifiers)) return;
 
    evas_object_smart_callback_call(e_gadget_site_get(pw->desk->pager->inst->o_pager), "gadget_site_unlocked", NULL);
-
-   pw->drag.button = 0;
 }
 
 static void
@@ -2013,6 +2002,7 @@ _pager_window_cb_mouse_down(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EI
 {
    Evas_Event_Mouse_Down *ev = event_info;
    Pager_Win *pw;
+
    if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return;
    if (_pager_check_modifiers(ev->modifiers)) return;
 
@@ -2054,8 +2044,6 @@ _pager_window_cb_mouse_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EI
    Evas_Coord x, y, w, h;
    const char *drag_types[] =
    { "enlightenment/pager_win", "enlightenment/border" };
-   Evas_Coord dx, dy;
-   unsigned int resist = 0;
    pw = data;
 
    if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return;
@@ -2068,13 +2056,8 @@ _pager_window_cb_mouse_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EI
    /* prevent drag for a few pixels */
    if (!pw->drag.start) return;
 
-   dx = pw->drag.x - ev->cur.output.x;
-   dy = pw->drag.y - ev->cur.output.y;
-   if (pw->desk->pager)
-     resist = pager_config->drag_resist;
-
-   if (((unsigned int)(dx * dx) + (unsigned int)(dy * dy)) <=
-       (resist * resist)) return;
+   if (!is_dragged(pw->drag.x - ev->cur.output.x,
+                   pw->drag.y - ev->cur.output.y)) return;
 
    pw->desk->pager->dragging = 1;
    pw->drag.start = 0;
@@ -2095,6 +2078,7 @@ _pager_window_cb_mouse_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EI
                      _pager_window_cb_drag_convert,
                      _pager_window_cb_drag_finished);
    drag->button_mask = evas_pointer_button_down_mask_get(e_comp->evas);
+   evas_object_raise(pw->client->frame);
    if ((pw->desk->pager->plain) || (pager_config->permanent_plain))
      {
         o = edje_object_add(drag->evas);
@@ -2154,6 +2138,7 @@ _pager_window_cb_drag_finished(E_Drag *drag, int dropped)
         /* be helpful */
         if (pw->client->desk->visible && (!e_client_focused_get()))
           evas_object_focus_set(pw->client->frame, 1);
+        e_deskmirror_update_force(pw->desk->o_layout);
      }
    else
      {
@@ -2189,6 +2174,7 @@ _pager_window_cb_drag_finished(E_Drag *drag, int dropped)
 
         if (!(ec->lock_user_stacking)) evas_object_raise(ec->frame);
         evas_object_focus_set(ec->frame, 1);
+        e_deskmirror_update_force(pw->desk->o_layout);
      }
    edje_object_signal_emit(pw->desk->o_desk, "e,action,drag,out", "e");
    if (!pw->drag.from_pager)
@@ -2229,10 +2215,11 @@ _pager_update_drop_position(Pager *p, Pager_Desk *pd, Evas_Coord x, Evas_Coord y
    if (!pw) return;
    if (pd)
      {
-        int zx, zy, zw, zh, vx, vy;
+        int zx, zy, zw, zh, vx, vy, offx, offy;
         E_Client *ec = pw->client;
         E_Desk *old_desk = ec->desk;
         Eina_Bool was_focused = e_client_stack_focused_get(ec);
+        E_Drag *drag = e_drag_current_get();
 
         pw->drag.in_pager = 1;
         //makes drags look weird
@@ -2240,12 +2227,18 @@ _pager_update_drop_position(Pager *p, Pager_Desk *pd, Evas_Coord x, Evas_Coord y
         zx = pd->desk->zone->x, zy = pd->desk->zone->y;
         zw = pd->desk->zone->w, zh = pd->desk->zone->h;
         e_deskmirror_coord_canvas_to_virtual(pd->o_layout,
-                                             x + pw->drag.dx,
-                                             y + pw->drag.dy, &vx, &vy);
+                                             x, y, &vx, &vy);
         ec->hidden = !pd->desk->visible;
         e_client_desk_set(ec, pd->desk);
-        x = E_CLAMP(vx + zx, zx, zx + zw - ec->w);
-        y = E_CLAMP(vy + zy, zy, zy + zh - ec->h);
+        offx = (ec->w / 2);
+        offy = (ec->h / 2);
+        if (drag)
+          {
+             if (drag->w > 0) offx = ((drag->dx) * ec->w) / drag->w;
+             if (drag->h > 0) offy = ((drag->dy) * ec->h) / drag->h;
+          }
+        x = E_CLAMP(vx + zx - offx, zx, zx + zw - ec->w);
+        y = E_CLAMP(vy + zy - offy, zy, zy + zh - ec->h);
         evas_object_move(ec->frame, x, y);
         if (was_focused)
           e_desk_last_focused_focus(old_desk);
@@ -2303,7 +2296,6 @@ _pager_drop_cb_drop(void *data, const char *type, void *event_info)
    Pager_Desk *pd, *pdd;
    Pager_Desk *pd2 = NULL;
    E_Client *ec = NULL;
-   int dx = 0, dy = 0;
    Pager_Win *pw = NULL;
    Evas_Coord wx, wy, wx2, wy2;
    Evas_Coord nx, ny;
@@ -2320,8 +2312,6 @@ _pager_drop_cb_drop(void *data, const char *type, void *event_info)
              if (pw)
                {
                   ec = pw->client;
-                  dx = pw->drag.dx;
-                  dy = pw->drag.dy;
                }
           }
         else if (!strcmp(type, "enlightenment/border"))
@@ -2341,8 +2331,6 @@ _pager_drop_cb_drop(void *data, const char *type, void *event_info)
                   e_deskmirror_coord_virtual_to_canvas(pd->o_layout, ec->x + ec->w,
                                                        ec->y + ec->h, &wx2, &wy2);
                }
-             dx = (wx - wx2) / 2;
-             dy = (wy - wy2) / 2;
           }
         else if (!strcmp(type, "enlightenment/vdesktop"))
           {
@@ -2373,28 +2361,38 @@ _pager_drop_cb_drop(void *data, const char *type, void *event_info)
 
              if ((!max) && (!fullscreen))
                {
-                  int zx, zy, zw, zh, mx, my;
+                  E_Drag *drag = e_drag_current_get();
+                  int zx, zy, zw, zh, mx, my, offx, offy;
+
                   if ((pd->pager->plain) || (pager_config->permanent_plain))
                     {
-                       e_layout_coord_canvas_to_virtual(pd->o_layout, ev->x + dx, ev->y + dy,
+                       e_layout_coord_canvas_to_virtual(pd->o_layout,
+                                                        ev->x, ev->y,
                                                         &nx, &ny);
                     }
                   else
                     {
                        e_deskmirror_coord_canvas_to_virtual(pd->o_layout,
-                                                            ev->x + dx,
-                                                            ev->y + dy,
+                                                            ev->x, ev->y,
                                                             &nx, &ny);
                     }
                   e_zone_useful_geometry_get(pd->desk->zone,
                                              &zx, &zy, &zw, &zh);
 
-                  mx = E_CLAMP(nx + zx, zx, zx + zw - ec->w);
-                  my = E_CLAMP(ny + zy, zy, zy + zh - ec->h);
+                  offx = (ec->w / 2);
+                  offy = (ec->h / 2);
+                  if (drag)
+                    {
+                       if (drag->w > 0) offx = ((drag->dx) * ec->w) / drag->w;
+                       if (drag->h > 0) offy = ((drag->dy) * ec->h) / drag->h;
+                    }
+                  mx = E_CLAMP(nx + zx - offx, zx, zx + zw - ec->w);
+                  my = E_CLAMP(ny + zy - offy, zy, zy + zh - ec->h);
                   evas_object_move(ec->frame, mx, my);
                }
              if (max) e_client_maximize(ec, max);
              if (fullscreen) e_client_fullscreen(ec, fs);
+             e_deskmirror_update_force(pd->o_layout);
           }
         EINA_LIST_FOREACH(pd->pager->desks, l, pdd)
           {
@@ -2442,12 +2440,18 @@ _pager_desk_cb_mouse_up(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_U
    Pager_Desk *pd;
    Pager *p;
 
-   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return;
-   if (_pager_check_modifiers(ev->modifiers)) return;
-
    pd = data;
 
    if (!pd) return;
+
+   if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD)
+     {
+        pd->drag.start = 0;
+        pd->drag.in_pager = 0;
+        return;
+     }
+   if (_pager_check_modifiers(ev->modifiers)) return;
+
    p = pd->pager;
 
    /* FIXME: pd->pager->dragging is 0 when finishing a drag from desk to desk */
@@ -2475,8 +2479,6 @@ _pager_desk_cb_mouse_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA
 {
    Evas_Event_Mouse_Move *ev = event_info;
    Pager_Desk *pd;
-   Evas_Coord dx, dy;
-   unsigned int resist = 0;
    E_Drag *drag;
    Evas_Object *o;
    Evas_Coord x, y, w, h;
@@ -2490,14 +2492,8 @@ _pager_desk_cb_mouse_move(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA
    /* prevent drag for a few pixels */
    if (pd->drag.start)
      {
-        dx = pd->drag.x - ev->cur.output.x;
-        dy = pd->drag.y - ev->cur.output.y;
-        if ((pd->pager) && (pd->pager->inst))
-          resist = pager_config->drag_resist;
-
-        if (((unsigned int)(dx * dx) + (unsigned int)(dy * dy)) <=
-            (resist * resist)) return;
-
+        if (!is_dragged(pd->drag.x - ev->cur.output.x,
+                        pd->drag.y - ev->cur.output.y)) return;
         if (pd->pager) pd->pager->dragging = 1;
         pd->drag.start = 0;
      }
@@ -2973,8 +2969,6 @@ pager_create(Evas_Object *parent, int *id, E_Gadget_Site_Orient orient EINA_UNUS
    evas_object_smart_callback_add(parent, "gadget_created", _pager_gadget_created_cb, inst);
    evas_object_smart_callback_add(parent, "gadget_site_anchor", _pager_gadget_anchor_change_cb, inst);
    evas_object_event_callback_add(o, EVAS_CALLBACK_MOVE, _pager_cb_move, inst);
-   evas_object_event_callback_add(o, EVAS_CALLBACK_MOUSE_DOWN,
-                                  _button_cb_mouse_down, inst);
    evas_object_event_callback_add(o, EVAS_CALLBACK_SHOW,
                                   _pager_cb_obj_show, inst);
    evas_object_event_callback_add(o, EVAS_CALLBACK_HIDE,
