@@ -77,7 +77,7 @@ _cpuclock_set_governor(const char *governor)
 #if defined(__FreeBSD__) || defined(__DragonFly__) || defined(__OpenBSD__)
    return;
 #endif
-   char buf[4096], exe[4096];
+   char buf[4096 + 100], exe[4096];
    struct stat st;
 
    snprintf(exe, 4096, "%s/%s/cpuclock_sysfs",
@@ -86,13 +86,14 @@ _cpuclock_set_governor(const char *governor)
 
    snprintf(buf, sizeof(buf),
             "%s %s %s", exe, "governor", governor);
-   system(buf);
+   if (system(buf) != 0)
+     ERR("Error code from trying to run \"%s\"", buf);
 }
 
 void
 _cpuclock_set_frequency(int frequency)
 {
-   char buf[4096], exe[4096];
+   char buf[4096 + 100], exe[4096];
    struct stat st;
 
 #if defined(__FreeBSD__) || defined(__DragonFly__)
@@ -104,14 +105,16 @@ _cpuclock_set_frequency(int frequency)
             e_module_dir_get(sysinfo_config->module), MODULE_ARCH);
    if (stat(exe, &st) < 0) return;
    snprintf(buf, sizeof(buf), "%s %d", exe, frequency);
-   system(buf);
+   if (system(buf) != 0)
+     ERR("Error code from trying to run \"%s\"", buf);
 #else
    snprintf(exe, 4096, "%s/%s/cpuclock_sysfs",
             e_module_dir_get(sysinfo_config->module), MODULE_ARCH);
    if (stat(exe, &st) < 0) return;
    snprintf(buf, sizeof(buf),
             "%s %s %i", exe, "frequency", frequency);
-   system(buf);
+   if (system(buf) != 0)
+     ERR("Error code from trying to run \"%s\"", buf);
 #endif
 }
 
@@ -121,7 +124,7 @@ _cpuclock_set_pstate(int min, int max, int turbo)
 #if defined(__FreeBSD__) || defined(__DragonFly__) || defined(__OpenBSD__)
    return;
 #endif
-   char buf[4096], exe[4096];
+   char buf[4096 + 100], exe[4096];
    struct stat st;
 
    snprintf(exe, 4096, "%s/%s/cpuclock_sysfs",
@@ -129,7 +132,8 @@ _cpuclock_set_pstate(int min, int max, int turbo)
    if (stat(exe, &st) < 0) return;
    snprintf(buf, sizeof(buf),
             "%s %s %i %i %i", exe, "pstate", min, max, turbo);
-   system(buf);
+   if (system(buf) != 0)
+     ERR("Error code from trying to run \"%s\"", buf);
 }
 
 static void
@@ -310,15 +314,15 @@ _cpuclock_popup_create(Instance *inst)
    elm_table_pack(table, label, 0, 0, 2, 1);
    evas_object_show(label);    
 
-   snprintf(buf, sizeof(buf), "%1.1f %s (%d %%)", f, u,
+   snprintf(buf, sizeof(buf), "%1.1f %s (%d %%%%)", f, u,
                  inst->cfg->cpuclock.percent);
 
    pbar = elm_progressbar_add(table);
    E_EXPAND(pbar);
    E_FILL(pbar);
    elm_progressbar_span_size_set(pbar, 200 * e_scale);
-   elm_progressbar_value_set(pbar, (float)inst->cfg->cpuclock.percent / 100);
    elm_progressbar_unit_format_set(pbar, buf);
+   elm_progressbar_value_set(pbar, (float)inst->cfg->cpuclock.percent / 100);
    elm_table_pack(table, pbar, 0, 1, 2, 1);
    evas_object_show(pbar);
    inst->cfg->cpuclock.popup_pbar = pbar;
@@ -331,30 +335,19 @@ _cpuclock_popup_create(Instance *inst)
 }
 
 static void
-_cpuclock_mouse_down_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_data)
+_cpuclock_mouse_up_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_data)
 {
-   Evas_Event_Mouse_Down *ev = event_data;
+   Evas_Event_Mouse_Up *ev = event_data;
    Instance *inst = data;
 
    if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return;
-   if (ev->button != 3)
+   if (ev->button == 1)
      {
         if (inst->cfg->cpuclock.popup)
           elm_ctxpopup_dismiss(inst->cfg->cpuclock.popup);
         else
           inst->cfg->cpuclock.popup = _cpuclock_popup_create(inst);
      }
-   else
-     {
-        if (inst->cfg->cpuclock.popup)
-          elm_ctxpopup_dismiss(inst->cfg->cpuclock.popup);
-        if (!sysinfo_config) return;
-        ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
-        if (inst->cfg->esm != E_SYSINFO_MODULE_CPUCLOCK)
-          cpuclock_configure(inst);
-        else
-          e_gadget_configure(inst->o_main);
-     }
 }
 
 void
@@ -472,7 +465,7 @@ _cpuclock_face_update_current(Instance *inst)
              f /= 1000000;
              u = _("GHz");
           }
-        snprintf(buf, sizeof(buf), "%1.1f %s (%d %%)", f, u,
+        snprintf(buf, sizeof(buf), "%1.1f %s (%d %%%%)", f, u,
                  inst->cfg->cpuclock.percent);
         elm_progressbar_unit_format_set(inst->cfg->cpuclock.popup_pbar, buf);
         elm_progressbar_value_set(inst->cfg->cpuclock.popup_pbar,
@@ -1084,8 +1077,8 @@ _cpuclock_created_cb(void *data, Evas_Object *obj, void *event_data EINA_UNUSED)
    evas_object_event_callback_add(inst->cfg->cpuclock.o_gadget, EVAS_CALLBACK_RESIZE, _cpuclock_resize_cb, inst);
    elm_box_pack_end(inst->o_main, inst->cfg->cpuclock.o_gadget);
    evas_object_event_callback_add(inst->cfg->cpuclock.o_gadget,
-                                  EVAS_CALLBACK_MOUSE_DOWN,
-                                  _cpuclock_mouse_down_cb, inst);
+                                  EVAS_CALLBACK_MOUSE_UP,
+                                  _cpuclock_mouse_up_cb, inst);
    evas_object_show(inst->cfg->cpuclock.o_gadget);
    evas_object_smart_callback_del_full(obj, "gadget_created", _cpuclock_created_cb, data);
 
@@ -1127,8 +1120,8 @@ sysinfo_cpuclock_create(Evas_Object *parent, Instance *inst)
    E_EXPAND(inst->cfg->cpuclock.o_gadget);
    E_FILL(inst->cfg->cpuclock.o_gadget);
    evas_object_event_callback_add(inst->cfg->cpuclock.o_gadget,
-                                  EVAS_CALLBACK_MOUSE_DOWN,
-                                  _cpuclock_mouse_down_cb, inst);
+                                  EVAS_CALLBACK_MOUSE_UP,
+                                  _cpuclock_mouse_up_cb, inst);
    edje_object_signal_callback_add(elm_layout_edje_get(inst->cfg->cpuclock.o_gadget), "e,action,governor,next", "*",
                                    _cpuclock_face_cb_set_governor, inst);
    edje_object_signal_callback_add(elm_layout_edje_get(inst->cfg->cpuclock.o_gadget), "e,action,frequency,increase", "*",
