@@ -34,33 +34,33 @@ _memusage_popup_update(Instance *inst)
         val_mb = inst->cfg->memusage.mem_used / 1024;
         val_perc = 100 * ((float)inst->cfg->memusage.mem_used /
                           (float)inst->cfg->memusage.mem_total);
-        snprintf(buf, sizeof(buf), "%d MB (%d %%)", val_mb, val_perc);
-        elm_progressbar_value_set(pbar, (float)val_perc / 100);
+        snprintf(buf, sizeof(buf), "%d MB (%d %%%%)", val_mb, val_perc);
         elm_progressbar_unit_format_set(pbar, buf);
+	elm_progressbar_value_set(pbar, (float)val_perc / 100);
 
         pbar = evas_object_data_get(inst->cfg->memusage.popup, "mem_buffers_pbar");
         val_mb = inst->cfg->memusage.mem_buffers / 1024;
         val_perc = 100 * ((float)inst->cfg->memusage.mem_buffers /
                           (float)inst->cfg->memusage.mem_total);
-        snprintf(buf, sizeof(buf), "%d MB (%d %%)", val_mb, val_perc);
-        elm_progressbar_value_set(pbar, (float)val_perc / 100);
+        snprintf(buf, sizeof(buf), "%d MB (%d %%%%)", val_mb, val_perc);
         elm_progressbar_unit_format_set(pbar, buf);
+	elm_progressbar_value_set(pbar, (float)val_perc / 100);
 
         pbar = evas_object_data_get(inst->cfg->memusage.popup, "mem_cached_pbar");
         val_mb = inst->cfg->memusage.mem_cached / 1024;
         val_perc = 100 * ((float)inst->cfg->memusage.mem_cached /
                           (float)inst->cfg->memusage.mem_total);
-        snprintf(buf, sizeof(buf), "%d MB (%d %%)", val_mb, val_perc);
-        elm_progressbar_value_set(pbar, (float)val_perc / 100);
+        snprintf(buf, sizeof(buf), "%d MB (%d %%%%)", val_mb, val_perc);
         elm_progressbar_unit_format_set(pbar, buf);
+	elm_progressbar_value_set(pbar, (float)val_perc / 100);
 
         pbar = evas_object_data_get(inst->cfg->memusage.popup, "mem_shared_pbar");
         val_mb = inst->cfg->memusage.mem_shared / 1024;
         val_perc = 100 * ((float)inst->cfg->memusage.mem_shared /
                           (float)inst->cfg->memusage.mem_total);
-        snprintf(buf, sizeof(buf), "%d MB (%d %%)", val_mb, val_perc);
-        elm_progressbar_value_set(pbar, (float)val_perc / 100);
+        snprintf(buf, sizeof(buf), "%d MB (%d %%%%)", val_mb, val_perc);
         elm_progressbar_unit_format_set(pbar, buf);
+	elm_progressbar_value_set(pbar, (float)val_perc / 100);
      }
 
    if (inst->cfg->memusage.swp_total)
@@ -69,9 +69,9 @@ _memusage_popup_update(Instance *inst)
         val_mb = inst->cfg->memusage.swp_used / 1024;
         val_perc = 100 * ((float)inst->cfg->memusage.swp_used /
                           (float)inst->cfg->memusage.swp_total);
-        snprintf(buf, sizeof(buf), "%d MB (%d %%)", val_mb, val_perc);
-        elm_progressbar_value_set(pbar, (float)val_perc / 100);
+        snprintf(buf, sizeof(buf), "%d MB (%d %%%%)", val_mb, val_perc);
         elm_progressbar_unit_format_set(pbar, buf);
+	elm_progressbar_value_set(pbar, (float)val_perc / 100);
      }
 }
 
@@ -129,7 +129,7 @@ static Evas_Object *
 _memusage_popup_create(Instance *inst)
 {
    Evas_Object *popup, *table, *label, *pbar;
-   char buf[128], buf2[128];
+   char buf[128], buf2[128 + 100];
 
    popup = elm_ctxpopup_add(e_comp->elm);
    elm_object_style_set(popup, "noblock");
@@ -237,13 +237,13 @@ _memusage_popup_create(Instance *inst)
 }
 
 static void
-_memusage_mouse_down_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_data)
+_memusage_mouse_up_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_data)
 {
-   Evas_Event_Mouse_Down *ev = event_data;
+   Evas_Event_Mouse_Up *ev = event_data;
    Instance *inst = data;
 
    if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return;
-   if (ev->button != 3)
+   if (ev->button == 1)
      {
         if (inst->cfg->memusage.popup)
           elm_ctxpopup_dismiss(inst->cfg->memusage.popup);
@@ -253,17 +253,6 @@ _memusage_mouse_down_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_U
              _memusage_popup_update(inst);
           }
      }
-   else
-     {
-        if (inst->cfg->memusage.popup)
-          elm_ctxpopup_dismiss(inst->cfg->memusage.popup);
-        if (!sysinfo_config) return;
-        ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
-        if (inst->cfg->esm != E_SYSINFO_MODULE_MEMUSAGE)
-          memusage_configure(inst);
-        else
-          e_gadget_configure(inst->o_main);
-     }
 }
 
 static void
@@ -471,8 +460,8 @@ _memusage_created_cb(void *data, Evas_Object *obj, void *event_data EINA_UNUSED)
    E_FILL(inst->cfg->memusage.o_gadget);
    elm_box_pack_end(inst->o_main, inst->cfg->memusage.o_gadget);
    evas_object_event_callback_add(inst->cfg->memusage.o_gadget,
-                                  EVAS_CALLBACK_MOUSE_DOWN,
-                                  _memusage_mouse_down_cb, inst);
+                                  EVAS_CALLBACK_MOUSE_UP,
+                                  _memusage_mouse_up_cb, inst);
    evas_object_event_callback_add(inst->cfg->memusage.o_gadget,
                                   EVAS_CALLBACK_RESIZE,
                                   _memusage_resize_cb, inst);
@@ -507,8 +496,8 @@ sysinfo_memusage_create(Evas_Object *parent, Instance *inst)
    E_EXPAND(inst->cfg->memusage.o_gadget);
    E_FILL(inst->cfg->memusage.o_gadget);
    evas_object_event_callback_add(inst->cfg->memusage.o_gadget,
-                                  EVAS_CALLBACK_MOUSE_DOWN,
-                                  _memusage_mouse_down_cb, inst);
+                                  EVAS_CALLBACK_MOUSE_UP,
+                                  _memusage_mouse_up_cb, inst);
    evas_object_event_callback_add(inst->cfg->memusage.o_gadget,
                                   EVAS_CALLBACK_RESIZE,
                                   _memusage_resize_cb, inst);
