@@ -42,19 +42,19 @@ _netstatus_face_update(Thread_Config *thc)
    if (thc->inst->cfg->netstatus.popup)
      {
         char buf[4096];
-        snprintf(buf, sizeof(buf), "%s (%d %%)",
+        snprintf(buf, sizeof(buf), "%s (%d %%%%)",
                 thc->inst->cfg->netstatus.instring,
                 thc->inst->cfg->netstatus.inpercent);
+        elm_progressbar_unit_format_set(thc->inst->cfg->netstatus.popup_inpbar, buf);
         elm_progressbar_value_set(thc->inst->cfg->netstatus.popup_inpbar,
                                   (float)thc->inst->cfg->netstatus.inpercent / 100);
-        elm_progressbar_unit_format_set(thc->inst->cfg->netstatus.popup_inpbar, buf);
         memset(buf, 0x00, sizeof(buf));
-        snprintf(buf, sizeof(buf), "%s (%d %%)",
+        snprintf(buf, sizeof(buf), "%s (%d %%%%)",
                 thc->inst->cfg->netstatus.outstring,
                 thc->inst->cfg->netstatus.outpercent);
+        elm_progressbar_unit_format_set(thc->inst->cfg->netstatus.popup_outpbar, buf);
         elm_progressbar_value_set(thc->inst->cfg->netstatus.popup_outpbar,
                                   (float)thc->inst->cfg->netstatus.outpercent / 100);
-        elm_progressbar_unit_format_set(thc->inst->cfg->netstatus.popup_outpbar, buf);
      }
 }
 
@@ -84,15 +84,15 @@ _netstatus_popup_deleted(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_
 }
 
 static void
-_netstatus_mouse_down_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_data)
+_netstatus_mouse_up_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_UNUSED, void *event_data)
 {
    Evas_Object *label, *popup, *table, *pbar;
-   Evas_Event_Mouse_Down *ev = event_data;
+   Evas_Event_Mouse_Up *ev = event_data;
    Instance *inst = data;
    char text[4096], buf[4096];
 
    if (ev->event_flags & EVAS_EVENT_FLAG_ON_HOLD) return;
-   if (ev->button != 3)
+   if (ev->button == 1)
      {
         if (inst->cfg->netstatus.popup)
           {
@@ -124,7 +124,7 @@ _netstatus_mouse_down_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_
         elm_table_pack(table, label, 0, 1, 1, 1);
         evas_object_show(label);
 
-        snprintf(buf, sizeof(buf), "%s (%d %%)",
+        snprintf(buf, sizeof(buf), "%s (%d %%%%)",
                 inst->cfg->netstatus.instring,
                 inst->cfg->netstatus.inpercent);
 
@@ -132,6 +132,7 @@ _netstatus_mouse_down_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_
         E_EXPAND(pbar);
         E_FILL(pbar);
         elm_progressbar_span_size_set(pbar, 200 * e_scale);
+        elm_progressbar_unit_format_set(pbar, buf);
         elm_progressbar_value_set(pbar, (float)inst->cfg->netstatus.inpercent / 100);
         elm_table_pack(table, pbar, 1, 1, 1, 1);
         evas_object_show(pbar);
@@ -144,7 +145,7 @@ _netstatus_mouse_down_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_
         evas_object_show(label);
 
         memset(buf, 0x00, sizeof(buf));
-        snprintf(buf, sizeof(buf), "%s (%d %%)",
+        snprintf(buf, sizeof(buf), "%s (%d %%%%)",
                 inst->cfg->netstatus.outstring,
                 inst->cfg->netstatus.outpercent);
 
@@ -152,8 +153,8 @@ _netstatus_mouse_down_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_
         E_EXPAND(pbar);
         E_FILL(pbar);
         elm_progressbar_span_size_set(pbar, 200 * e_scale);
-        elm_progressbar_value_set(pbar, (float)inst->cfg->netstatus.outpercent / 100);
         elm_progressbar_unit_format_set(pbar, buf);
+	elm_progressbar_value_set(pbar, (float)inst->cfg->netstatus.outpercent / 100);
         elm_table_pack(table, pbar, 1, 2, 1, 1);
         evas_object_show(pbar);
         inst->cfg->netstatus.popup_outpbar = pbar;
@@ -163,17 +164,6 @@ _netstatus_mouse_down_cb(void *data, Evas *e EINA_UNUSED, Evas_Object *obj EINA_
         evas_object_show(popup);
         inst->cfg->netstatus.popup = popup;
      }
-   else
-     {
-        if (inst->cfg->netstatus.popup)
-          elm_ctxpopup_dismiss(inst->cfg->netstatus.popup);
-        if (!sysinfo_config) return;
-        ev->event_flags |= EVAS_EVENT_FLAG_ON_HOLD;
-        if (inst->cfg->esm != E_SYSINFO_MODULE_NETSTATUS)
-          netstatus_configure(inst);
-        else
-          e_gadget_configure(inst->o_main);
-     }
 }
 
 static void
@@ -422,7 +412,7 @@ _netstatus_created_cb(void *data, Evas_Object *obj, void *event_data EINA_UNUSED
    E_EXPAND(inst->cfg->netstatus.o_gadget);
    E_FILL(inst->cfg->netstatus.o_gadget);
    elm_box_pack_end(inst->o_main, inst->cfg->netstatus.o_gadget);
-   evas_object_event_callback_add(inst->cfg->netstatus.o_gadget, EVAS_CALLBACK_MOUSE_DOWN, _netstatus_mouse_down_cb, inst);
+   evas_object_event_callback_add(inst->cfg->netstatus.o_gadget, EVAS_CALLBACK_MOUSE_UP, _netstatus_mouse_up_cb, inst);
    evas_object_event_callback_add(inst->cfg->netstatus.o_gadget, EVAS_CALLBACK_RESIZE, _netstatus_resize_cb, inst);
    evas_object_show(inst->cfg->netstatus.o_gadget);
    evas_object_smart_callback_del_full(obj, "gadget_created", _netstatus_created_cb, data);
@@ -447,7 +437,7 @@ sysinfo_netstatus_create(Evas_Object *parent, Instance *inst)
                            "e/gadget/netstatus/main");
    E_EXPAND(inst->cfg->netstatus.o_gadget);
    E_FILL(inst->cfg->netstatus.o_gadget);
-   evas_object_event_callback_add(inst->cfg->netstatus.o_gadget, EVAS_CALLBACK_MOUSE_DOWN, _netstatus_mouse_down_cb, inst);
+   evas_object_event_callback_add(inst->cfg->netstatus.o_gadget, EVAS_CALLBACK_MOUSE_UP, _netstatus_mouse_up_cb, inst);
    evas_object_event_callback_add(inst->cfg->netstatus.o_gadget, EVAS_CALLBACK_RESIZE, _netstatus_resize_cb, inst);
    evas_object_show(inst->cfg->netstatus.o_gadget);
 
