@@ -43,9 +43,10 @@ typedef struct Client_Extra
       const char *bordername;
    } orig;
    int       last_frame_adjustment; // FIXME: Hack for frame resize bug.
-   Eina_Bool floating : 1;
-   Eina_Bool tiled : 1;
-   Eina_Bool tracked : 1;
+   Eina_Bool floating E_BITFIELD;
+   Eina_Bool tiled E_BITFIELD;
+   Eina_Bool tracked E_BITFIELD;
+   Eina_Bool being_removed E_BITFIELD;
 } Client_Extra;
 
 typedef struct _Instance
@@ -478,7 +479,8 @@ _reapply_tree(void)
 
         if (zw > 0 && zh > 0)
           tiling_window_tree_apply(_G.tinfo->tree, zx, zy, zw, zh,
-                                   tiling_g.config->window_padding);
+                                   tiling_g.config->window_padding,
+                                   EINA_FALSE);
         else
           ERR("The zone desk geometry was not useful at all (%d,%d,%d,%d)", zx, zy, zw, zh);
      }
@@ -567,24 +569,23 @@ _desk_config_apply(E_Desk *d, int old_nb_stacks, int new_nb_stacks)
 static void
 _client_apply_settings(E_Client *ec, Client_Extra *extra)
 {
-   if (!extra)
-     {
-        extra = tiling_entry_func(ec);
-     }
+   const char *bdname = "pixel";
 
-   if (!extra || !extra->tiled)
-      return;
+   if (!extra) extra = tiling_entry_func(ec);
 
-   if (ec->maximized)
-     _e_client_unmaximize(ec, E_MAXIMIZE_BOTH);
+   if ((!extra) || (!extra->tiled)) return;
 
-   if (!tiling_g.config->show_titles && (!ec->bordername ||
-                                         strcmp(ec->bordername, "pixel")))
-     change_window_border(ec, "pixel");
-   else if (tiling_g.config->show_titles && (ec->bordername &&
-                                         !strcmp(ec->bordername, "pixel")))
-     change_window_border(ec, (extra->orig.bordername) ? extra->orig.bordername : "default");
+   if (ec->maximized) _e_client_unmaximize(ec, E_MAXIMIZE_BOTH);
 
+   if (e_theme_border_find("tiling")) bdname = "tiling";
+
+   if ((!tiling_g.config->show_titles) &&
+       (!ec->bordername || strcmp(ec->bordername, bdname)))
+     change_window_border(ec, bdname);
+   else if ((tiling_g.config->show_titles) &&
+            (ec->bordername && !strcmp(ec->bordername, bdname)))
+     change_window_border(ec, (extra->orig.bordername) ?
+                          extra->orig.bordername : "default");
 }
 
 static void
@@ -794,6 +795,8 @@ _client_remove_no_apply(E_Client *ec)
         return EINA_FALSE;
      }
 
+   extra->being_removed = EINA_TRUE;
+
    if (extra->drag.drag)
      {
         _client_drag_terminate(ec);
@@ -841,6 +844,8 @@ toggle_floating(E_Client *ec)
         return;
      }
 
+   if (extra->being_removed) return;
+
    extra->floating = !extra->floating;
 
    if (!desk_should_tile_check(ec->desk))
@@ -865,17 +870,15 @@ tiling_e_client_does_not_fit(E_Client *ec)
    Eina_Strbuf *buf;
 
    buf = eina_strbuf_new();
-   if (ec->netwm.name)
-     eina_strbuf_append_printf(buf, "Window %s cannot be tiled\n", ec->netwm.name);
-   else
-     eina_strbuf_append(buf, "A Window cannot be tiled\n");
+   eina_strbuf_append_printf(buf, _("Window %s cannot be tiled\n"),
+                             e_client_util_name_get(ec));
 
    memset(&n, 0, sizeof(n));
    n.app_name = _("Tiling");
    n.icon.icon = "dialog-error";
    n.summary = _("Window cannot be tiled");
    n.body = eina_strbuf_string_get(buf);
-   n.timeout = 2000;
+   n.timeout = 8000;
    e_notification_client_send(&n, NULL, NULL);
    toggle_floating(ec);
 
@@ -1054,7 +1057,7 @@ _tiling_split_type_changed_popup(void)
      {
         _G.split_popup.obj = o = edje_object_add(e_comp->evas);
         if (!e_theme_edje_object_set(o, "base/theme/modules/tiling",
-                 "modules/tiling/main"))
+                 "e/modules/tiling/main"))
            edje_object_file_set(o, _G.edj_path, "modules/tiling/main");
         evas_object_resize(o, TILING_POPUP_SIZE, TILING_POPUP_SIZE);
 
@@ -1145,7 +1148,8 @@ _move_or_resize(E_Client *ec)
      {
         return;
      }
-
+/* This seems to create more issues than it seemingly solves? it stops
+ * resizes when no borders are there....
    if (!extra->last_frame_adjustment)
      {
         printf
@@ -1153,7 +1157,7 @@ _move_or_resize(E_Client *ec)
         _reapply_tree();
         return;
      }
-
+ */
    Window_Tree *item = tiling_window_tree_client_find(_G.tinfo->tree, ec);
 
    if (!item)
@@ -1680,7 +1684,7 @@ _client_drag_mouse_move(void *data, int event EINA_UNUSED, void *event_info)
         extra->drag.hint = edje_object_add(e_comp->evas);
         if (!e_theme_edje_object_set(extra->drag.hint,
                                      "base/theme/modules/tiling",
-                                     "modules/tiling/indicator"))
+                                     "e/modules/tiling/indicator"))
           edje_object_file_set(extra->drag.hint, _G.edj_path, "modules/tiling/indicator");
         evas_object_layer_set(extra->drag.hint, E_LAYER_CLIENT_DRAG);
         evas_object_show(extra->drag.hint);
@@ -1834,10 +1838,8 @@ e_modapi_init(E_Module *m)
    _G.info_hash = eina_hash_pointer_new(_clear_info_hash);
    _G.client_extras = eina_hash_pointer_new(_clear_border_extras);
    _G.desk_type = eina_hash_pointer_new(_clear_desk_types);
-#define HANDLER(_h, _e, _f)                                \
-  _h = ecore_event_handler_add(E_EVENT_##_e,               \
-                               (Ecore_Event_Handler_Cb)_f, \
-                               NULL);
+#define HANDLER(_h, _e, _f) \
+  _h = ecore_event_handler_add(E_EVENT_##_e, (void *)_f, NULL)
 
    _G.handler_client_resize_begin =
       e_client_hook_add(E_CLIENT_HOOK_RESIZE_BEGIN, _resize_begin_hook, NULL);
@@ -2173,7 +2175,7 @@ _gc_init(E_Gadcon *gc, const char *name, const char *id, const char *style)
 
    o = edje_object_add(gc->evas);
    if (!e_theme_edje_object_set(o, "base/theme/modules/tiling",
-                                "modules/tiling/main"))
+                                "e/modules/tiling/main"))
      edje_object_file_set(o, _G.edj_path, "modules/tiling/main");
    evas_object_show(o);
 
