@@ -9,8 +9,8 @@ struct _E_Winlist_Win
    Evas_Object  *bg_object;
    Evas_Object  *icon_object;
    E_Client     *client;
-   unsigned char was_iconified : 1;
-   unsigned char was_shaded : 1;
+   unsigned char was_iconified E_BITFIELD;
+   unsigned char was_shaded E_BITFIELD;
 };
 
 static void      _e_winlist_size_adjust(void);
@@ -73,6 +73,12 @@ _wmclass_picked(const Eina_List *lst, const char *wmclass)
    return EINA_FALSE;
 }
 
+static void
+_cb_lost(void *data EINA_UNUSED)
+{
+   e_winlist_hide();
+}
+
 /* externally accessible functions */
 int
 e_winlist_init(void)
@@ -101,24 +107,31 @@ e_winlist_show(E_Zone *zone, E_Winlist_Filter filter)
    E_OBJECT_CHECK_RETURN(zone, 0);
    E_OBJECT_TYPE_CHECK_RETURN(zone, E_ZONE_TYPE, 0);
 
-   if (_winlist) return 0;
+   if (_winlist) return 1;
 
 #ifndef HAVE_WAYLAND_ONLY
    if (e_comp->comp_type == E_PIXMAP_TYPE_X)
      {
+        Ecore_X_Window mouse_grab = 0;
         _input_window = ecore_x_window_input_new(e_comp->root, 0, 0, 1, 1);
         ecore_x_window_show(_input_window);
-        if (!e_grabinput_get(_input_window, 0, _input_window))
+        if (_activate_type == E_WINLIST_ACTIVATE_TYPE_MOUSE)
+          mouse_grab = _input_window;
+        if (!e_grabinput_get(mouse_grab, 0, _input_window))
           {
              ecore_x_window_free(_input_window);
              _input_window = 0;
              return 0;
           }
+        e_grabinput_lost_cb_set(_cb_lost, NULL);
      }
 #endif
    if (e_comp->comp_type != E_PIXMAP_TYPE_X)
      {
-        if (!e_comp_grab_input(1, 1))
+        Eina_Bool mouse_grab = EINA_FALSE;
+        if (_activate_type == E_WINLIST_ACTIVATE_TYPE_MOUSE)
+          mouse_grab = EINA_TRUE;
+        if (!e_comp_grab_input(mouse_grab, EINA_TRUE))
           return 0;
         _input_window = e_comp->ee_win;
      }
@@ -149,6 +162,7 @@ e_winlist_show(E_Zone *zone, E_Winlist_Filter filter)
 
    evas_event_freeze(e_comp->evas);
    o = edje_object_add(e_comp->evas);
+   evas_object_pass_events_set(o, EINA_TRUE);
    _winlist = e_comp_object_util_add(o, E_COMP_OBJECT_TYPE_POPUP);
    evas_object_layer_set(_winlist, E_LAYER_CLIENT_POPUP);
    evas_object_move(_winlist, x, y);
@@ -213,14 +227,8 @@ e_winlist_show(E_Zone *zone, E_Winlist_Filter filter)
      ecore_evas_pointer_xy_get(e_comp->ee,
                             &_last_pointer_x, &_last_pointer_y);
 
-   _e_winlist_activate_nth(1);
+   _e_winlist_activate_nth(0);
 
-   if ((eina_list_count(_wins) > 1))
-     {
-        ww = eina_list_data_get(_win_selected);
-        if (ww && (ww->client == _last_client))
-          e_winlist_next();
-     }
    evas_event_thaw(e_comp->evas);
    _e_winlist_size_adjust();
 
@@ -552,11 +560,9 @@ e_winlist_direction_select(E_Zone *zone, int dir)
    _e_winlist_activate();
 }
 
-
 void
 e_winlist_modifiers_set(int mod, E_Winlist_Activate_Type type)
 {
-   if (!_winlist) return;
    _hold_mod = mod;
    _hold_count = 0;
    _activate_type = type;
