@@ -56,9 +56,9 @@ typedef struct Connman_Technology
    Eldbus_Proxy *proxy;
    Eina_Stringshare *tethering_ssid;
    Eina_Stringshare *tethering_passwd;
-   Eina_Bool powered : 1;
-   Eina_Bool connected : 1;
-   Eina_Bool tethering : 1;
+   Eina_Bool powered E_BITFIELD;
+   Eina_Bool connected E_BITFIELD;
+   Eina_Bool tethering E_BITFIELD;
 } Connman_Technology;
 
 typedef struct
@@ -110,8 +110,8 @@ typedef struct
    Eina_Stringshare *proxy_url;
    Eina_Array *proxy_servers;
    Eina_Array *proxy_excludes;
-   Eina_Bool ipv6 : 1;
-   Eina_Bool favorite : 1;
+   Eina_Bool ipv6 E_BITFIELD;
+   Eina_Bool favorite E_BITFIELD;
 } Connman_Service;
 
 typedef enum
@@ -1186,7 +1186,7 @@ _connman_agent_auth_send(void *data, const Eina_Array *fields)
 {
    Eldbus_Message *reply;
    Eldbus_Message_Iter *iter, *array;
-   const char *f, *fprev;
+   const char *f, *fprev = NULL;
    unsigned int i;
    Eina_Array_Iterator it;
 
@@ -1204,7 +1204,7 @@ _connman_agent_auth_send(void *data, const Eina_Array *fields)
 
    EINA_ARRAY_ITER_NEXT(fields, i, f, it)
      {
-        if (i % 2)
+        if ((i % 2) && (fprev))
           _connman_dbus_dict_append_string(array, fprev, f);
         else
           fprev = f;
