@@ -1,8 +1,7 @@
 /* Splash Screen */
 
 #include "e_wizard.h"
-
-static Ecore_Timer *_next_timer = NULL;
+#include "e_wizard_api.h"
 
 /*
 E_API int
@@ -17,37 +16,22 @@ wizard_page_shutdown(E_Wizard_Page *pg EINA_UNUSED)
    return 1;
 }
 */
-static Eina_Bool
-_next_page(void *data EINA_UNUSED)
-{
-   _next_timer = NULL;
-   e_wizard_button_next_enable_set(1);
-   e_wizard_next();
-   return ECORE_CALLBACK_CANCEL;
-}
 
 E_API int
 wizard_page_show(E_Wizard_Page *pg EINA_UNUSED)
 {
    Evas_Object *o;
 
-   e_wizard_title_set(_("Enlightenment"));
-   e_wizard_button_next_enable_set(0);
+   api->wizard_title_set(_("Enlightenment"));
    o = edje_object_add(pg->evas);
    e_theme_edje_object_set(o, "base/theme/wizard", "e/wizard/firstpage");
-   e_wizard_page_show(o);
-
-   /* advance in 1 sec */
-   if (!_next_timer)
-     _next_timer = ecore_timer_loop_add(1.0, _next_page, NULL);
+   api->wizard_page_show(o);
    return 1;
 }
 
 E_API int
 wizard_page_hide(E_Wizard_Page *pg EINA_UNUSED)
 {
-   if (_next_timer) ecore_timer_del(_next_timer);
-   _next_timer = NULL;
    return 1;
 }
 /*
