@@ -374,7 +374,7 @@ _xdg_shell_surface_send_configure(struct wl_resource *resource, Eina_Bool fullsc
    zxdg_surface_v6_send_configure(shd->surface, serial);
 
    wl_array_release(&states);
-   ec->comp_data->need_xdg6_configure = 0;
+   ec->comp_data->need_xdg_configure = 0;
 }
 
 static void
@@ -400,7 +400,7 @@ _e_xdg_shell_surface_configure_send(struct wl_resource *resource, uint32_t edges
         serial = wl_display_next_serial(e_comp_wl->wl.disp);
         zxdg_popup_v6_send_configure(resource, ec->x - ec->parent->x, ec->y - ec->parent->y, width ?: ec->w, height ?: ec->h);
         zxdg_surface_v6_send_configure(shd->surface, serial);
-        ec->comp_data->need_xdg6_configure = 0;
+        ec->comp_data->need_xdg_configure = 0;
         return;
      }
 
@@ -582,7 +582,7 @@ _e_xdg_toplevel_cb_maximized_unset(struct wl_client *client EINA_UNUSED, struct
 }
 
 static void
-_e_xdg_toplevel_cb_fullscreen_set(struct wl_client *client EINA_UNUSED, struct wl_resource *resource, struct wl_resource *output_resource EINA_UNUSED)
+_e_xdg_toplevel_cb_fullscreen_set(struct wl_client *client EINA_UNUSED, struct wl_resource *resource, struct wl_resource *output_resource)
 {
    E_Client *ec;
 
@@ -596,6 +596,17 @@ _e_xdg_toplevel_cb_fullscreen_set(struct wl_client *client EINA_UNUSED, struct w
      }
 
    if (ec->lock_user_fullscreen) return;
+   if (output_resource)
+     {
+        Eina_List *l;
+        E_Zone *zone;
+        E_Comp_Wl_Output *wlo = wl_resource_get_user_data(output_resource);
+        EINA_LIST_FOREACH(e_comp->zones, l, zone)
+          if (zone->output == wlo)
+            ec->comp_data->shell.set.fs_zone = zone->id;
+     }
+   else
+     ec->comp_data->shell.set.fs_zone = ec->zone->id;
    _xdg_shell_surface_send_configure(resource, 1, !!ec->maximized || ec->comp_data->max, 0, ec->zone->w, ec->zone->h);
 }
 
@@ -664,22 +675,32 @@ _apply_positioner_x(int x, Positioner *p, Eina_Bool invert)
         grav = p->gravity;
      }
 
-   /* left edge */
-   if (an & ZXDG_POSITIONER_V6_ANCHOR_LEFT)
-     x += p->anchor_rect.x;
-   /* right edge */
-   else if (an & ZXDG_POSITIONER_V6_ANCHOR_RIGHT)
-     x += p->anchor_rect.x + p->anchor_rect.w;
-   /* center */
-   else
-     x += p->anchor_rect.x + (p->anchor_rect.w / 2);
+   switch (an)
+     {
+      case ZXDG_POSITIONER_V6_ANCHOR_LEFT:
+        x += p->anchor_rect.x;
+        break;
+      case ZXDG_POSITIONER_V6_ANCHOR_RIGHT:
+        x += p->anchor_rect.x + p->anchor_rect.w;
+        break;
+      default:
+        x += p->anchor_rect.x + (p->anchor_rect.w / 2);
+        break;
+     }
+
+   switch (grav)
+     {
+      case ZXDG_POSITIONER_V6_GRAVITY_LEFT:
+        x -= p->size.w;
+        break;
+      case ZXDG_POSITIONER_V6_GRAVITY_RIGHT:
+        x = x;
+        break;
+      default:
+        x -= p->size.w / 2;
+        break;
+     }
 
-   /* flip left over anchor */
-   if (grav & ZXDG_POSITIONER_V6_GRAVITY_LEFT)
-     x -= p->size.w;
-   /* center on anchor */
-   else if (!(grav & ZXDG_POSITIONER_V6_GRAVITY_RIGHT))
-     x -= p->size.w / 2;
    return x;
 }
 
@@ -706,22 +727,31 @@ _apply_positioner_y(int y, Positioner *p, Eina_Bool invert)
         grav = p->gravity;
      }
 
-   /* up edge */
-   if (an & ZXDG_POSITIONER_V6_ANCHOR_TOP)
-     y += p->anchor_rect.y;
-   /* bottom edge */
-   else if (an & ZXDG_POSITIONER_V6_ANCHOR_BOTTOM)
-     y += p->anchor_rect.y + p->anchor_rect.h;
-   /* center */
-   else
-     y += p->anchor_rect.y + (p->anchor_rect.h / 2);
+   switch (an)
+     {
+      case ZXDG_POSITIONER_V6_ANCHOR_TOP:
+        y += p->anchor_rect.y;
+        break;
+      case ZXDG_POSITIONER_V6_ANCHOR_BOTTOM:
+        y += p->anchor_rect.y + p->anchor_rect.h;
+        break;
+      default:
+        y += p->anchor_rect.y + (p->anchor_rect.h / 2);
+        break;
+     }
+
+   switch (grav)
+     {
+      case ZXDG_POSITIONER_V6_GRAVITY_TOP:
+        y -= p->size.h;
+        break;
+      case ZXDG_POSITIONER_V6_GRAVITY_BOTTOM:
+        y = y;
+        break;
+      default:
+        y -= (p->size.h / 2);
+     }
 
-   /* flip up over anchor */
-   if (grav & ZXDG_POSITIONER_V6_GRAVITY_TOP)
-     y -= p->size.h;
-   /* center on anchor */
-   else if (!(grav & ZXDG_POSITIONER_V6_GRAVITY_BOTTOM))
-     y -= p->size.h / 2;
    return y;
 }
 
@@ -798,8 +828,8 @@ _apply_positioner(E_Client *ec, Positioner *p)
     - gravity (perform flips if gravity is not right|bottom)
     - constrain (adjust if popup does not fit)
     */
-   ec->x = _apply_positioner_x(ec->x, p, 0);
-   ec->y = _apply_positioner_y(ec->y, p, 0);
+   ec->x = _apply_positioner_x(x, p, 0);
+   ec->y = _apply_positioner_y(y, p, 0);
 
    e_zone_useful_geometry_get(ec->parent->zone, &zx, &zy, &zw, &zh);
 
@@ -931,7 +961,7 @@ _e_xdg_surface_cb_popup_get(struct wl_client *client, struct wl_resource *resour
    cdata->shell.configure = _e_xdg_shell_surface_configure;
    cdata->shell.map = _e_xdg_shell_surface_map;
    cdata->shell.unmap = _e_xdg_shell_surface_unmap;
-   cdata->need_xdg6_configure = 1;
+   cdata->need_xdg_configure = 1;
 
    if (!ec->internal)
      ec->borderless = !ec->internal_elm_win;
@@ -1234,7 +1264,7 @@ _e_xdg_surface_cb_toplevel_get(struct wl_client *client EINA_UNUSED, struct wl_r
    cdata->shell.configure = _e_xdg_shell_surface_configure;
    cdata->shell.map = _e_xdg_shell_surface_map;
    cdata->shell.unmap = _e_xdg_shell_surface_unmap;
-   cdata->need_xdg6_configure = 1;
+   cdata->need_xdg_configure = 1;
 
    /* set toplevel client properties */
    ec->icccm.accepts_focus = 1;
@@ -1280,6 +1310,14 @@ _e_xdg_shell_surface_cb_destroy(struct wl_resource *resource)
    e_shell_surface_cb_destroy(resource);
 }
 
+static void
+_e_xdg_shell_surface_buffer_attach_error(E_Client *ec)
+{
+   wl_resource_post_error(ec->comp_data->surface,
+                               ZXDG_SURFACE_V6_ERROR_UNCONFIGURED_BUFFER,
+                               "buffer attached/committed before configure");
+}
+
 static void
 _e_xdg_shell_cb_surface_get(struct wl_client *client, struct wl_resource *resource, uint32_t id, struct wl_resource *surface_resource)
 {
@@ -1340,6 +1378,7 @@ _e_xdg_shell_cb_surface_get(struct wl_client *client, struct wl_resource *resour
    e_object_ref(E_OBJECT(ec));
 
    cdata->shell.ping = _e_xdg_shell_surface_ping;
+   cdata->shell.buffer_attach_error = _e_xdg_shell_surface_buffer_attach_error;
    cdata->is_xdg_surface = EINA_TRUE;
 
    if (!ec->internal)
