@@ -39,7 +39,7 @@ typedef struct
    Ecore_X_Atom selection;
    Ecore_X_Atom property;
    Eina_Binbuf *buf;
-   Eina_Bool incr : 1;
+   Eina_Bool incr E_BITFIELD;
 } Pipe;
 
 static Ecore_X_Window owner_win;
@@ -186,52 +186,56 @@ _xwl_fixes_selection_notify(void *d EINA_UNUSED, int t EINA_UNUSED, Ecore_X_Even
                   Ecore_X_Atom *types = (void*)data;
 
                   names = malloc(num * sizeof(void*));
-                  namelist = eina_array_new(num);
-                  for (i = 0; i < num; i++)
+                  if (names)
                     {
-                       char *name;
-
-                       if (types[i] == string_atom)
+                       namelist = eina_array_new(num);
+                       for (i = 0; i < num; i++)
                          {
-                            name = names[i] = strdup("UTF8_STRING");
-                            eina_array_push(namelist, eina_stringshare_add(WL_TEXT_STR));
-                         }
-                       else
-                         names[i] = name = ecore_x_atom_name_get(types[i]);
-                       DBG("XWL TARGET: %s", name);
-                       eina_array_push(namelist, eina_stringshare_add(name));
-                    }
-                  if (num > 3)
-                    {
-                       ecore_x_window_prop_property_set(e_comp->cm_selection,
-                         ECORE_X_ATOM_XDND_TYPE_LIST, ECORE_X_ATOM_ATOM, 32, names, num);
-                    }
+                            char *name;
 
+                            if (types[i] == string_atom)
+                              {
+                                 name = names[i] = strdup("UTF8_STRING");
+                                 eina_array_push(namelist, eina_stringshare_add(WL_TEXT_STR));
+                              }
+                            else
+                              names[i] = name = ecore_x_atom_name_get(types[i]);
+                            DBG("XWL TARGET: %s", name);
+                            eina_array_push(namelist, eina_stringshare_add(name));
+                         }
+                       if (num > 3)
+                         {
+                            ecore_x_window_prop_property_set(e_comp->cm_selection,
+                                                             ECORE_X_ATOM_XDND_TYPE_LIST, ECORE_X_ATOM_ATOM, 32, names, num);
+                         }
+                    }
                   free(data);
                }
-             evas_pointer_canvas_xy_get(e_comp->evas, &x, &y);
-             e_comp_wl->drag_client = e_pixmap_find_client(E_PIXMAP_TYPE_X, ev->owner);
-             if (!e_comp_wl->drag_client) e_comp_wl->drag_client = e_comp_wl->ptr.ec;
-             e_comp_wl->drag = e_drag_new(x, y, (const char**)names, num, NULL, 0, NULL, _xwayland_drop);
-             e_comp_wl->drag->button_mask = evas_pointer_button_down_mask_get(e_comp->evas);
-             ecore_x_window_move_resize(e_comp->cm_selection, 0, 0, e_comp->w, e_comp->h);
-             ecore_x_window_show(e_comp->cm_selection);
-             e_drag_start(e_comp_wl->drag, x, y);
-             if (e_comp_wl->ptr.ec)
-               e_comp_wl_data_device_send_enter(e_comp_wl->ptr.ec);
-             e_comp_canvas_feed_mouse_up(0);
-             source = e_comp_wl_data_manager_source_create(e_comp_wl->xwl_client,
-               e_comp_wl->mgr.resource, 0);
-             source->current_dnd_action = WL_DATA_DEVICE_MANAGER_DND_ACTION_COPY;
-             source->dnd_actions = WL_DATA_DEVICE_MANAGER_DND_ACTION_COPY;
-             e_comp_wl->drag_source = source;
-             source->target = _xwayland_target_send;
-             source->send = _xwayland_send_send;
-             source->cancelled = _xwayland_cancelled_send;
-             source->mime_types = namelist;
-             for (i = 0; i < num; i++)
-               free(names[i]);
-             free(names);
+             if (names)
+               {
+                  evas_pointer_canvas_xy_get(e_comp->evas, &x, &y);
+                  e_comp_wl->drag_client = e_pixmap_find_client(E_PIXMAP_TYPE_X, ev->owner);
+                  if (!e_comp_wl->drag_client) e_comp_wl->drag_client = e_comp_wl->ptr.ec;
+                  e_comp_wl->drag = e_drag_new(x, y, (const char**)names, num, NULL, 0, NULL, _xwayland_drop);
+                  e_comp_wl->drag->button_mask = evas_pointer_button_down_mask_get(e_comp->evas);
+                  ecore_x_window_move_resize(e_comp->cm_selection, 0, 0, e_comp->w, e_comp->h);
+                  ecore_x_window_show(e_comp->cm_selection);
+                  e_drag_start(e_comp_wl->drag, x, y);
+                  if (e_comp_wl->ptr.ec)
+                    e_comp_wl_data_device_send_enter(e_comp_wl->ptr.ec);
+                  e_comp_canvas_feed_mouse_up(0);
+                  source = e_comp_wl_data_manager_source_create(e_comp_wl->xwl_client,
+                                                                e_comp_wl->mgr.resource, 0);
+                  source->current_dnd_action = WL_DATA_DEVICE_MANAGER_DND_ACTION_COPY;
+                  source->dnd_actions = WL_DATA_DEVICE_MANAGER_DND_ACTION_COPY;
+                  e_comp_wl->drag_source = source;
+                  source->target = _xwayland_target_send;
+                  source->send = _xwayland_send_send;
+                  source->cancelled = _xwayland_cancelled_send;
+                  source->mime_types = namelist;
+                  for (i = 0; i < num; i++) free(names[i]);
+                  free(names);
+               }
           }
         else
           {
@@ -270,7 +274,7 @@ typedef struct Xfer_Data
 {
    EINA_INLIST;
    Eina_Binbuf *buf;
-   Eina_Bool xdnd : 1;
+   Eina_Bool xdnd E_BITFIELD;
    unsigned int offset;
    Ecore_Fd_Handler *fdh;
 } Xfer_Data;
@@ -363,13 +367,9 @@ _xwl_pipe_read(void *data, Ecore_Fd_Handler *fdh)
    unsigned char *buf;
 
    buf = malloc(INCR_CHUNK_SIZE);
+   if (!buf) goto err;
+
    len = read(ecore_main_fd_handler_fd_get(fdh), (void*)buf, INCR_CHUNK_SIZE);
-   if (len < 0)
-     {
-        free(buf);
-        _incr_update(p, 0);
-        eina_hash_del_by_key(pipes, &p->win);
-     }
    if (len == INCR_CHUNK_SIZE)
      {
         p->buf = eina_binbuf_manage_new(buf, len, 0);
@@ -386,16 +386,28 @@ _xwl_pipe_read(void *data, Ecore_Fd_Handler *fdh)
         ecore_main_fd_handler_active_set(p->fdh, 0);
         return ECORE_CALLBACK_RENEW;
      }
-   if (len)
-     p->buf = eina_binbuf_manage_new(buf, len, 0);
+   else if (len > 0)
+     {
+        p->buf = eina_binbuf_manage_new(buf, len, 0);
+     }
+   else
+     {
+        _incr_update(p, 0);
+        eina_hash_del_by_key(pipes, &p->win);
+        free(buf);
+        return ECORE_CALLBACK_RENEW;
+     }
    _incr_upload(p);
    if (p->incr)
-     ecore_main_fd_handler_active_set(p->fdh, 0);
+     {
+        ecore_main_fd_handler_active_set(p->fdh, 0);
+     }
    else
      {
         _incr_update(p, 1);
         eina_hash_del_by_key(pipes, &p->win);
      }
+err:
    return ECORE_CALLBACK_RENEW;
 }
 
@@ -448,21 +460,30 @@ _xwl_selection_request(void *d EINA_UNUSED, int t EINA_UNUSED, Ecore_X_Event_Sel
                E_Client *ec;
                int fds[2];
 
+               if (socketpair(AF_UNIX, (SOCK_STREAM | SOCK_CLOEXEC), 0, fds) != 0)
+                 break;
+               if (fcntl(fds[0], F_SETFL, O_NONBLOCK) != 0)
+                 {
+                    close(fds[0]);
+                    close(fds[1]);
+                    break;
+                 }
                p = E_NEW(Pipe, 1);
-               socketpair(AF_UNIX, (SOCK_STREAM | SOCK_CLOEXEC), 0, fds);
-               fcntl(fds[0], F_SETFL, O_NONBLOCK);
-               p->fdh = ecore_main_fd_handler_add(fds[0], ECORE_FD_READ, _xwl_pipe_read, p, NULL, NULL);
-               p->win = ev->requestor;
-               p->source = source;
-               wl_data_source_send_send(source->resource, type, fds[1]);
-               close(fds[1]);
-               p->atom = ev->target;
-               p->selection = ev->selection;
-               p->property = ev->property;
-               ec = e_pixmap_find_client(E_PIXMAP_TYPE_X, ev->requestor);
-               if (ec && ec->override)
-                 ecore_x_window_sniff(ev->requestor);
-               eina_hash_add(pipes, &p->win, p);
+               if (p)
+                 {
+                    p->fdh = ecore_main_fd_handler_add(fds[0], ECORE_FD_READ, _xwl_pipe_read, p, NULL, NULL);
+                    p->win = ev->requestor;
+                    p->source = source;
+                    wl_data_source_send_send(source->resource, type, fds[1]);
+                    close(fds[1]);
+                    p->atom = ev->target;
+                    p->selection = ev->selection;
+                    p->property = ev->property;
+                    ec = e_pixmap_find_client(E_PIXMAP_TYPE_X, ev->requestor);
+                    if (ec && ec->override)
+                      ecore_x_window_sniff(ev->requestor);
+                    eina_hash_add(pipes, &p->win, p);
+                 }
                break;
             }
      }
